#[repr(i64)]pub enum NSApplicationActivationPolicy {
Regular = 0,
Accessory = 1,
Prohibited = 2,
}Expand description
Activation policies (used by activationPolicy) that control whether and how an app may be activated.
Variants
Regular = 0
The application is an ordinary app that appears in the Dock and may have a user interface.
Accessory = 1
The application doesn’t appear in the Dock and doesn’t have a menu bar, but it may be activated programmatically or by clicking on one of its windows.
Prohibited = 2
The application doesn’t appear in the Dock and may not create windows or be activated.