NSWindowCollectionBehavior

Enum NSWindowCollectionBehavior 

#[repr(u64)]
pub enum NSWindowCollectionBehavior {
Show 13 variants Default = 0, CanJoinAllSpaces = 1, MoveToActiveSpace = 2, Managed = 4, Transient = 8, Stationary = 16, ParticipatesInCycle = 32, IgnoresCycle = 64, FullScreenPrimary = 128, FullScreenAuxiliary = 256, FullScreenNone = 512, FullScreenAllowsTiling = 2_048, FullScreenDisallowsTiling = 4_096,
}
Window collection behaviors related to Exposé and Spaces.

Variants



Default = 0

The window appears in only one space at a time.



CanJoinAllSpaces = 1

The window appears in all spaces.



MoveToActiveSpace = 2

When the window becomes active, move it to the active space instead of switching spaces.



Managed = 4

The window participates in Spaces and Exposé.



Transient = 8

The window floats in Spaces and hides in Exposé.



Stationary = 16

Exposé doesn’t affect the window, so it stays visible and stationary, like the desktop window.



ParticipatesInCycle = 32

The window participates in the window cycle for use with the Cycle Through Windows menu item.



IgnoresCycle = 64

The window isn’t part of the window cycle for use with the Cycle Through Windows menu item.



FullScreenPrimary = 128

The window can enter full-screen mode.



FullScreenAuxiliary = 256

The window can display on the same space as the full-screen window.



FullScreenNone = 512

The window doesn’t support full-screen mode.



FullScreenAllowsTiling = 2_048

The window can be a secondary full screen tile even if it can’t be a full screen window itself.



FullScreenDisallowsTiling = 4_096

The window doesn’t support being a full-screen tile window, but may support being a full-screen window.