NSWindowOcclusionState

Enum NSWindowOcclusionState 

#[repr(u64)]
pub enum NSWindowOcclusionState { Visible = 2, }
Specifies whether the window is occluded.

Variants



Visible = 2

If set, at least part of the window is visible; if not set, the entire window is occluded. A window that has a nonrectangular shape can be entirely occluded onscreen, but if its bounding box falls into a visible region, the window is considered to be visible. Note that a completely transparent window may also be considered visible.