#[repr(C)]pub struct NSNib {
pub ptr: Id<Object>,
}Expand description
An object that manages an app’s menus.
Fields
ptr: Id<Object>The raw pointer to the Objective-C object.
Implementations
Sourceimpl NSNib
impl NSNib
Sourcepub fn init_with_contents_of_url(&mut self, nib_file_url: NSURL) -> id
👎Deprecated: use [init_with_nib_data_bundle] instead.
pub fn init_with_contents_of_url(&mut self, nib_file_url: NSURL) -> id
init_with_nib_data_bundle] instead.Returns an NSNib object initialized to the nib file at the specified URL.
Sourcepub fn init_with_nib_named_bundle(
&mut self,
nib_name: NSNibName,
bundle: &NSBundle,
) -> Self
pub fn init_with_nib_named_bundle( &mut self, nib_name: NSNibName, bundle: &NSBundle, ) -> Self
Returns an NSNib object initialized to the nib file in the specified bundle.
Sourcepub fn init_with_nib_data_bundle(
&mut self,
nib_data: &NSData,
bundle: &NSBundle,
) -> Self
pub fn init_with_nib_data_bundle( &mut self, nib_data: &NSData, bundle: &NSBundle, ) -> Self
Initializes an instance with nib data and specified bundle for locating resources.
Sourcepub fn instantiate_nib_with_owner_top_level_objects<T>(
&mut self,
owner: id,
top_lvl_objects: &NSArray<T>,
) -> bool
👎Deprecated: use [instantiate_with_owner_top_level_objects] instead.
pub fn instantiate_nib_with_owner_top_level_objects<T>( &mut self, owner: id, top_lvl_objects: &NSArray<T>, ) -> bool
instantiate_with_owner_top_level_objects] instead.Unarchives and instantiates the in-memory contents of the receiver’s nib file, creating a distinct object tree and set of top level objects.
Sourcepub fn instantiate_nib_with_external_name_table<K, V>(
&self,
external_name_table: &NSDictionary<K, V>,
) -> bool
👎Deprecated: use [instantiate_with_owner_top_level_objects] instead.
pub fn instantiate_nib_with_external_name_table<K, V>( &self, external_name_table: &NSDictionary<K, V>, ) -> bool
instantiate_with_owner_top_level_objects] instead.Unarchives and instantiates the in-memory contents of the receiver’s nib file, creating a distinct object tree and top level objects.
Sourcepub fn instantiate_with_owner_top_level_objects<T>(
&self,
owner: id,
top_lvl_objects: Option<NSArray<T>>,
)
pub fn instantiate_with_owner_top_level_objects<T>( &self, owner: id, top_lvl_objects: Option<NSArray<T>>, )
Instantiates objects in the nib file with the specified owner.
Methods from Deref<Target = Object>
Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Returns a reference to the ivar of self with the given name.
Panics if self has no ivar with the given name.
Unsafe because the caller must ensure that the ivar is actually
of type T.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Returns a mutable reference to the ivar of self with the given name.
Panics if self has no ivar with the given name.
Unsafe because the caller must ensure that the ivar is actually
of type T.