INSPopover

Trait INSPopover 

pub trait INSPopover: INSResponder {
Show 20 methods // Provided methods fn p_content_view_controller(&self) -> NSViewController { ... } fn p_set_content_view_controller<Controller>( &self, view_controller: Controller, ) where Controller: INSViewController { ... } fn p_behavior(&self) -> NSPopoverBehavior { ... } fn p_set_behavior(&self, behavior: NSPopoverBehavior) { ... } fn m_show_relative_to_rect_of_view_preferred_edge<V>( &self, rect: NSRect, view: V, edge: CGRectEdge, ) where V: INSView { ... } fn p_positioning_rect(&self) -> NSRect { ... } fn p_appearance(&self) -> NSAppearance { ... } fn m_set_appearance(&self, appearance: NSAppearance) { ... } fn p_effective_appearance(&self) -> NSAppearance { ... } fn p_animates(&self) -> bool { ... } fn p_content_size(&self) -> NSSize { ... } fn p_set_content_size(&self, size: NSSize) { ... } fn p_shown(&self) -> bool { ... } fn p_detached(&self) -> bool { ... } fn m_perform_close(&self, sender: id) { ... } fn m_close(&self) { ... } fn p_delegate(&self) -> id { ... } fn m_set_delegate(&self, delegate: id) { ... } fn m_init(&self) -> NSPopover { ... } fn m_init_with_coder(&self, coder: NSCoder) -> NSPopover { ... }
}
A trait containing all the methods for NSPopover

Provided Methods

fn p_content_view_controller(&self) -> NSViewController

The view controller that manages the content of the popover.

fn p_set_content_view_controller<Controller>(&self, view_controller: Controller)
where Controller: INSViewController,

Sets the view controller that manages the content of the popover.

Arguments
  • view_controller - The view controller that manages the content of the popover.
fn p_behavior(&self) -> NSPopoverBehavior

Specifies the behavior of the popover.

fn p_set_behavior(&self, behavior: NSPopoverBehavior)

Sets the behavior of the popover.

Arguments
  • behavior - The behavior of the popover.
fn m_show_relative_to_rect_of_view_preferred_edge<V>( &self, rect: NSRect, view: V, edge: CGRectEdge, )
where V: INSView,

Shows the popover anchored to the specified view.

fn p_positioning_rect(&self) -> NSRect

The rectangle within the positioning view relative to which the popover should be positioned.

fn p_appearance(&self) -> NSAppearance

The appearance of the popover.

fn m_set_appearance(&self, appearance: NSAppearance)

Sets the appearance of the popover.

Arguments
  • appearance - The appearance to use.
fn p_effective_appearance(&self) -> NSAppearance

The appearance that will be used when the popover is displayed onscreen.

fn p_animates(&self) -> bool

Specifies if the popover is to be animated.

fn p_content_size(&self) -> NSSize

The content size of the popover.

fn p_set_content_size(&self, size: NSSize)

Sets the content size of the popover.

Arguments
  • size - The size to use.
fn p_shown(&self) -> bool

The display state of the popover.

fn p_detached(&self) -> bool

A Boolean value that indicates whether the window created by a popover’s detachment is automatically created.

fn m_perform_close(&self, sender: id)

Attempts to close the popover.

fn m_close(&self)

Forces the popover to close without consulting its delegate.

fn p_delegate(&self) -> id

The delegate of the popover.

fn m_set_delegate(&self, delegate: id)

Sets the delegate of the popover.

Arguments
  • delegate - The delegate to use.
fn m_init(&self) -> NSPopover

Creates a new popover.

fn m_init_with_coder(&self, coder: NSCoder) -> NSPopover

Creates a new popover with NSCoder

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors