INSRunningApplication

Trait INSRunningApplication 

pub trait INSRunningApplication: PNSObject {
    // Provided methods
    fn p_current_application() -> Self
       where Self: Sized + FromId { ... }
    fn p_is_active(&self) -> bool { ... }
    fn m_activate_with_options(
        &mut self,
        options: NSApplicationActivationOptions,
    ) { ... }
}
A trait containing all the methods for NSRunningApplication

Provided Methods

fn p_current_application() -> Self
where Self: Sized + FromId,

Returns the application instance, creating it if it doesn’t exist yet.

fn p_is_active(&self) -> bool

Indicates whether the application is currently frontmost.

fn m_activate_with_options(&mut self, options: NSApplicationActivationOptions)

Attempts to activate the application using the specified options.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors