INSStatusBar

Trait INSStatusBar 

pub trait INSStatusBar: PNSObject {
    // Provided methods
    fn p_system_status_bar() -> Self
       where Self: Sized + FromId { ... }
    fn m_status_item_with_length(&self, length: CGFloat) -> NSStatusItem { ... }
}
A trait containing all the methods for NSStatusBar

Provided Methods

fn p_system_status_bar() -> Self
where Self: Sized + FromId,

Returns the system-wide status bar located in the menu bar.

fn m_status_item_with_length(&self, length: CGFloat) -> NSStatusItem

Returns a newly created status item that has been allotted a specified space within the status bar.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors