pub trait INSStatusItem: PNSObject {
// Provided methods
fn p_status_bar(&self) -> NSStatusBar { ... }
fn p_behavior(&self) -> NSStatusItemBehavior { ... }
fn p_button(&self) -> Option<NSStatusBarButton> { ... }
fn p_menu(&self) -> NSMenu { ... }
fn p_visible(&self) -> bool { ... }
fn p_length(&self) -> CGFloat { ... }
}Expand description
A trait containing all the methods for NSStatusItem
Provided Methods
Sourcefn p_status_bar(&self) -> NSStatusBar
fn p_status_bar(&self) -> NSStatusBar
The status bar that displays the status item.
Sourcefn p_behavior(&self) -> NSStatusItemBehavior
fn p_behavior(&self) -> NSStatusItemBehavior
The set of allowed behaviors for the status item.
The button displayed in the status bar.
The pull-down menu displayed when the user clicks the status item.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".