INSTextField

Trait INSTextField 

pub trait INSTextField: INSControl {
    // Provided methods
    fn m_label_with_string(string: NSString) -> Self
       where Self: Sized + FromId { ... }
    fn m_text_field_with_string(string: NSString) -> Self
       where Self: Sized + FromId { ... }
    fn m_text_view_with_string(string: NSString) -> Self
       where Self: Sized + FromId { ... }
}
A trait containing all the methods for NSTextField

Provided Methods

fn m_label_with_string(string: NSString) -> Self
where Self: Sized + FromId,

Initializes a text field for use as a static label that uses the system default font, doesn’t wrap, and doesn’t have selectable text.

fn m_text_field_with_string(string: NSString) -> Self
where Self: Sized + FromId,

Initializes a single-line editable text field for user input using the system default font and standard visual appearance.

fn m_text_view_with_string(string: NSString) -> Self
where Self: Sized + FromId,

Initializes a text field for use as a multiline static label with selectable text that uses the system default font.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors