pub trait INSViewController: INSResponder {
// Provided methods
fn m_init_with_nib_name_bundle(
nib_name: NSNibName,
bundle: NSBundle,
) -> Self
where Self: Sized + FromId { ... }
fn m_load_view(&self) { ... }
fn p_represented_object(&self) -> id { ... }
fn p_nib_bundle(&self) -> NSBundle { ... }
fn p_nib_name(&self) -> NSNibName { ... }
fn p_view(&self) -> NSView { ... }
fn p_set_view<V>(&self, view: V)
where V: INSView { ... }
fn p_title(&self) -> id { ... }
fn p_set_title(&self, title: id) { ... }
fn p_view_did_load(&self) { ... }
}Expand description
A trait containing all the methods for NSViewController
Provided Methods
Sourcefn m_init_with_nib_name_bundle(nib_name: NSNibName, bundle: NSBundle) -> Self
fn m_init_with_nib_name_bundle(nib_name: NSNibName, bundle: NSBundle) -> Self
Returns a view controller object initialized to the nib file in the specified bundle.
Sourcefn m_load_view(&self)
fn m_load_view(&self)
Instantiates a view from a nib file and sets the value of the view property.
Sourcefn p_represented_object(&self) -> id
fn p_represented_object(&self) -> id
Returns the represented object of the view controller.
Sourcefn p_nib_bundle(&self) -> NSBundle
fn p_nib_bundle(&self) -> NSBundle
The nib bundle to be loaded to instantiate the receiver’s primary view.
Sourcefn p_nib_name(&self) -> NSNibName
fn p_nib_name(&self) -> NSNibName
The name of the nib file to be loaded to instantiate the receiver’s primary view.
Sourcefn p_set_view<V>(&self, view: V)where
V: INSView,
fn p_set_view<V>(&self, view: V)where
V: INSView,
Sourcefn p_set_title(&self, title: id)
fn p_set_title(&self, title: id)
Sets the localized title of the receiver’s primary view.
Arguments
title- The title to be set as the primary view.
Sourcefn p_view_did_load(&self)
fn p_view_did_load(&self)
Called after the view controller’s view has been loaded into memory.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".