Module background_tasks

Module background_tasks 

Request the system to launch your app in the background to run tasks.

Structs

BGAppRefreshTask
An object representing a short task typically used to refresh content that’s run while the app is in the background.
BGAppRefreshTaskRequest
A request to launch your app in the background to execute a short refresh task.
BGProcessingTask
A time-consuming processing task that runs while the app is in the background.
BGProcessingTaskRequest
A request to launch your app in the background to execute a processing task that can take minutes to complete.
BGTask
An abstract class representing a task that’s run while the app is in the background.
BGTaskRequest
An abstract class for representing task requests.
BGTaskScheduler
A class for scheduling task requests that launch your app in the background.

Traits

IBGAppRefreshTask
A trait containing all the methods for BGAppRefreshTask
IBGAppRefreshTaskRequest
A trait containing all the methods for BGAppRefreshTaskRequest
IBGProcessingTask
A trait containing all the methods for BGProcessingTask
IBGProcessingTaskRequest
A trait containing all the methods for BGProcessingTaskRequest
IBGTask
A trait containing all the methods for BGTask
IBGTaskRequest
A trait containing all the methods for BGTaskRequest
IBGTaskScheduler
A trait containing all the methods for BGTaskScheduler