IBGProcessingTaskRequest

Trait IBGProcessingTaskRequest 

pub trait IBGProcessingTaskRequest: IBGTaskRequest {
    // Provided methods
    fn m_init_with_identifier(&mut self, identifier: NSString) -> Self
       where Self: Sized + FromId { ... }
    fn p_requires_external_power() -> bool { ... }
    fn p_requires_network_connectivity() -> bool { ... }
}
A trait containing all the methods for BGProcessingTaskRequest

Provided Methods

fn m_init_with_identifier(&mut self, identifier: NSString) -> Self
where Self: Sized + FromId,

Return a new processing task request for the specified identifier.

fn p_requires_external_power() -> bool

A Boolean specifying if the processing task requires a device connected to power.

fn p_requires_network_connectivity() -> bool

A Boolean specifying if the processing task requires network connectivity.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors