IBGTask

Trait IBGTask 

pub trait IBGTask: PNSObject {
    // Provided methods
    fn p_identifier(&self) -> NSString { ... }
    fn p_expiration_handler(&self) { ... }
    fn m_set_task_completed_with_success(&mut self, success: bool) { ... }
}
A trait containing all the methods for BGTask

Provided Methods

fn p_identifier(&self) -> NSString

The identifier of the task.

fn p_expiration_handler(&self)

A handler called shortly before the task’s background time expires.

fn m_set_task_completed_with_success(&mut self, success: bool)

Informs the background task scheduler that the task is complete.

Arguments
  • success - A bool indicating if the task completed successfully or not.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors