#[repr(C)]pub struct CNChangeHistoryEvent {
pub ptr: Id<Object>,
}Expand description
Fields
ptr: Id<Object>The raw pointer to the Objective-C object.
Implementations
Sourceimpl CNChangeHistoryEvent
impl CNChangeHistoryEvent
Sourcepub fn accept_event_visitor(&self, visitor: id)
pub fn accept_event_visitor(&self, visitor: id)
Methods from Deref<Target = Object>
Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Returns a reference to the ivar of self with the given name.
Panics if self has no ivar with the given name.
Unsafe because the caller must ensure that the ivar is actually
of type T.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Returns a mutable reference to the ivar of self with the given name.
Panics if self has no ivar with the given name.
Unsafe because the caller must ensure that the ivar is actually
of type T.