ICNContactFetchRequest

Trait ICNContactFetchRequest 

pub trait ICNContactFetchRequest: ICNFetchRequest {
    // Provided methods
    fn m_init_with_keys_to_fetch(&self, keys: NSArray<id>) -> Self
       where Self: Sized + FromId { ... }
    fn p_predicate(&self) -> NSPredicate { ... }
    fn p_set_predicate(&mut self, predicate: NSPredicate) { ... }
    fn p_mutable_objects(&self) -> bool { ... }
    fn p_set_mutable_objects(&mut self, mutable_objects: bool) { ... }
    fn p_unify_results(&self) -> bool { ... }
    fn p_set_unify_results(&mut self, unify_results: bool) { ... }
    fn p_sort_order(&self) -> CNContactSortOrder { ... }
    fn p_keys_to_fetch(&self) -> NSArray<id> { ... }
    fn p_set_keys_to_fetch(&mut self, keys_to_fetch: NSArray<id>) { ... }
}
A trait containing all the methods for CNContactFetchRequest

Provided Methods

fn m_init_with_keys_to_fetch(&self, keys: NSArray<id>) -> Self
where Self: Sized + FromId,

Creates a fetch request for the specified keys.

fn p_predicate(&self) -> NSPredicate

The predicate to match contacts against.

fn p_set_predicate(&mut self, predicate: NSPredicate)

Sets the predicate to match contacts against.

fn p_mutable_objects(&self) -> bool

Configuring the Fetch Options

fn p_set_mutable_objects(&mut self, mutable_objects: bool)

Sets whether the fetch request should return mutable objects.

fn p_unify_results(&self) -> bool

A Boolean value that indicates whether to return linked contacts as unified contacts.

fn p_set_unify_results(&mut self, unify_results: bool)

Sets whether to return linked contacts as unified contacts.

fn p_sort_order(&self) -> CNContactSortOrder

The sort order for contacts.

fn p_keys_to_fetch(&self) -> NSArray<id>

The properties to fetch in the returned contacts.

fn p_set_keys_to_fetch(&mut self, keys_to_fetch: NSArray<id>)

Sets the properties to fetch in the returned contacts.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors