ICNInstantMessageAddress

Trait ICNInstantMessageAddress 

pub trait ICNInstantMessageAddress: PNSObject {
    // Provided methods
    fn m_init_with_username_service(
        &mut self,
        username: NSString,
        service: NSString,
    ) -> Self
       where Self: Sized + FromId { ... }
    fn p_service(&self) -> NSString { ... }
    fn p_username(&self) -> NSString { ... }
    fn m_localized_string_for_key(key: NSString) -> NSString { ... }
    fn m_localized_string_for_service(service: NSString) -> NSString { ... }
}
A trait containing all the methods for CNInstantMessageAddress

Provided Methods

fn m_init_with_username_service( &mut self, username: NSString, service: NSString, ) -> Self
where Self: Sized + FromId,

Returns a CNInstantMessageAddress object initialized with the specified user name and service.

fn p_service(&self) -> NSString

The service type of the instant message address.

fn p_username(&self) -> NSString

The username of the instant message address.

fn m_localized_string_for_key(key: NSString) -> NSString

Returns a string containing the localized property name.

fn m_localized_string_for_service(service: NSString) -> NSString

Returns a string containing the localized name of the specified service.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors