pub trait ICNLabeledValue<ValueType>: PNSObject{
// Provided methods
fn m_init_with_label_value(
&mut self,
label: &NSString,
value: ValueType,
) -> Self
where Self: Sized + FromId { ... }
fn m_labeled_value_with_label_value(
label: &NSString,
value: ValueType,
) -> Self
where Self: Sized + FromId { ... }
fn p_label(&self) -> NSString { ... }
fn p_value(&self) -> ValueType { ... }
fn m_labeled_value_by_setting_label(&self, label: &NSString) -> Self
where Self: Sized + FromId { ... }
fn m_labeled_value_by_setting_label_value(
&self,
label: &NSString,
value: ValueType,
) -> Self
where Self: Sized + FromId { ... }
fn m_labeled_value_by_setting_value(&self, value: ValueType) -> Self
where Self: Sized + FromId { ... }
fn m_localized_string_for_label(label: &NSString) -> NSString { ... }
fn p_identifier(&self) -> NSString { ... }
}Expand description
A trait containing all the methods for ICNLabeledValue“
Provided Methods
Sourcefn m_init_with_label_value(
&mut self,
label: &NSString,
value: ValueType,
) -> Self
fn m_init_with_label_value( &mut self, label: &NSString, value: ValueType, ) -> Self
Returns a new labeled value identifier.
Sourcefn m_labeled_value_with_label_value(label: &NSString, value: ValueType) -> Self
fn m_labeled_value_with_label_value(label: &NSString, value: ValueType) -> Self
Returns a new labeled value identifier.
Sourcefn m_labeled_value_by_setting_label(&self, label: &NSString) -> Self
fn m_labeled_value_by_setting_label(&self, label: &NSString) -> Self
Returns a labeled value object with an existing value and identifier.
Sourcefn m_labeled_value_by_setting_label_value(
&self,
label: &NSString,
value: ValueType,
) -> Self
fn m_labeled_value_by_setting_label_value( &self, label: &NSString, value: ValueType, ) -> Self
Returns a labeled value object with the specified label and value with the existing identifier.
Sourcefn m_labeled_value_by_setting_value(&self, value: ValueType) -> Self
fn m_labeled_value_by_setting_value(&self, value: ValueType) -> Self
Returns a new value for an existing label and identifier.
Sourcefn m_localized_string_for_label(label: &NSString) -> NSString
fn m_localized_string_for_label(label: &NSString) -> NSString
Returns a localized string for the specified label.
Sourcefn p_identifier(&self) -> NSString
fn p_identifier(&self) -> NSString
A unique identifier for the labeled value object.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.