ICNPhoneNumber

Trait ICNPhoneNumber 

pub trait ICNPhoneNumber: PNSObject {
    // Provided methods
    fn m_init_with_string_value(&mut self, phone_number: NSString) -> Self
       where Self: Sized + FromId { ... }
    fn m_phone_number_with_string_value(phone_number: NSString) -> Self
       where Self: Sized + FromId { ... }
    fn p_string_value(&self) -> NSString { ... }
}
A trait containing all the methods for CNPhoneNumber

Provided Methods

fn m_init_with_string_value(&mut self, phone_number: NSString) -> Self
where Self: Sized + FromId,

Returns a new phone number object initialized with the specified phone number string.

fn m_phone_number_with_string_value(phone_number: NSString) -> Self
where Self: Sized + FromId,

Returns a new phone number object initialized with the specified phone number string.

fn p_string_value(&self) -> NSString

The string value of the phone number.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors