ICNSaveRequest

Trait ICNSaveRequest 

pub trait ICNSaveRequest: PNSObject {
    // Provided methods
    fn m_add_contact_to_container_with_identifier<Contact>(
        &self,
        contact: Contact,
        identifier: Option<NSString>,
    )
       where Contact: ICNContact { ... }
    fn m_update_contact(&self, contact: CNMutableContact) { ... }
    fn m_delete_contact(&self, contact: CNMutableContact) { ... }
    fn m_add_group_to_container_with_identifier(
        &self,
        group: CNMutableGroup,
        identifier: NSString,
    ) { ... }
    fn m_update_group(&self, group: CNMutableGroup) { ... }
    fn m_delete_group(&self, group: CNMutableGroup) { ... }
    fn m_add_member_to_group<Contact, Group>(
        &self,
        contact: Contact,
        group: Group,
    )
       where Contact: ICNContact,
             Group: ICNGroup { ... }
    fn m_remove_member_from_group<Contact, Group>(
        &self,
        contact: Contact,
        group: Group,
    )
       where Contact: ICNContact,
             Group: ICNGroup { ... }
    fn m_add_subgroup_to_group<Group, ParentGroup>(
        &self,
        group: Group,
        parent_group: ParentGroup,
    )
       where Group: ICNGroup,
             ParentGroup: ICNGroup { ... }
    fn m_remove_subgroup_from_group<Group, ParentGroup>(
        &self,
        group: Group,
        parent_group: ParentGroup,
    )
       where Group: ICNGroup,
             ParentGroup: ICNGroup { ... }
    fn p_should_refetch_contacts(&self) -> bool { ... }
    fn p_transaction_author(&self) -> NSString { ... }
}
A trait containing all the methods for CNSaveRequest

Provided Methods

fn m_add_contact_to_container_with_identifier<Contact>( &self, contact: Contact, identifier: Option<NSString>, )
where Contact: ICNContact,

Adds the specified contact to the contact store.

Arguments
  • contact - The contact to add to the contact store.
  • container_identifier - The identifier of the container to add the new contact. To add the new contact to the default container set identifier to None.
fn m_update_contact(&self, contact: CNMutableContact)

Updates an existing contact in the contact store.

fn m_delete_contact(&self, contact: CNMutableContact)

Removes the specified contact from the contact store.

fn m_add_group_to_container_with_identifier( &self, group: CNMutableGroup, identifier: NSString, )

Adds a group to the contact store.

fn m_update_group(&self, group: CNMutableGroup)

Updates an existing group in the contact store.

fn m_delete_group(&self, group: CNMutableGroup)

Deletes a group from the contact store.

fn m_add_member_to_group<Contact, Group>(&self, contact: Contact, group: Group)
where Contact: ICNContact, Group: ICNGroup,

Adds a contact as a member of a group.

fn m_remove_member_from_group<Contact, Group>( &self, contact: Contact, group: Group, )
where Contact: ICNContact, Group: ICNGroup,

Removes a contact from a group.

fn m_add_subgroup_to_group<Group, ParentGroup>( &self, group: Group, parent_group: ParentGroup, )
where Group: ICNGroup, ParentGroup: ICNGroup,

Add the specified group to a parent group.

fn m_remove_subgroup_from_group<Group, ParentGroup>( &self, group: Group, parent_group: ParentGroup, )
where Group: ICNGroup, ParentGroup: ICNGroup,

Remove a subgroup from the specified parent group.

fn p_should_refetch_contacts(&self) -> bool

fn p_transaction_author(&self) -> NSString

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors