NSFormattingContext

Enum NSFormattingContext 

#[repr(i64)]
pub enum NSFormattingContext { Unknown = 0, Dynamic = 1, Standalone = 2, ListItem = 3, BeginningOfSentence = 4, MiddleOfSentence = 5, }
The formatting context for a formatter.

Variants



Unknown = 0

An unknown formatting context.



Dynamic = 1

A formatting context determined automatically at runtime.



Standalone = 2

The formatting context for stand-alone usage.



ListItem = 3

The formatting context for a list or menu item.



BeginningOfSentence = 4

The formatting context for the beginning of a sentence.



MiddleOfSentence = 5

The formatting context for the middle of a sentence.