#[repr(u64)]pub enum NSNumberFormatterPadPosition {
BeforePrefix = 0,
AfterPrefix = 1,
BeforeSuffix = 2,
AfterSuffix = 3,
}Expand description
These constants are used to specify how numbers should be padded. These constants are used by the paddingPosition property.
Variants
BeforePrefix = 0
Specifies that the padding should occur before the prefix.
AfterPrefix = 1
Specifies that the padding should occur after the prefix.
BeforeSuffix = 2
Specifies that the padding should occur before the suffix.
AfterSuffix = 3
Specifies that the padding should occur after the suffix.