#[repr(u64)]pub enum NSRoundingMode {
Plain = 0,
Down = 1,
Up = 2,
Bankers = 3,
}Expand description
These constants specify rounding behaviors.
Variants
Plain = 0
Round to the closest possible return value; when caught halfway between two positive numbers, round up; when caught between two negative numbers, round down.
Down = 1
Round return values down.
Up = 2
Round return values up.
Bankers = 3
Round to the closest possible return value; when halfway between two possibilities, return the possibility whose last digit is even.