NSDictionary

Struct NSDictionary 

pub struct NSDictionary<K, V> {
    pub ptr: ShareId<Object>,
    /* private fields */
}
A static collection of objects associated with unique keys.

Fields

ptr: ShareId<Object>

The raw pointer to the Objective-C object.

Implementations

Source

impl<K, V> NSDictionary<K, V>

pub fn new() -> Self

Returns an empty dictionary.

pub fn count(&self) -> UInt

The number of entries in the dictionary.

pub fn object_for_key(&self, key: K) -> Option<V>
where K: Clone, V: FromId,

Returns the value associated with a given key.

Methods from Deref<Target = Object>

pub fn class(&self) -> &Class

Returns the class of self.

pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

Returns a reference to the ivar of self with the given name. Panics if self has no ivar with the given name. Unsafe because the caller must ensure that the ivar is actually of type T.

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

Returns a mutable reference to the ivar of self with the given name. Panics if self has no ivar with the given name. Unsafe because the caller must ensure that the ivar is actually of type T.

pub unsafe fn set_ivar<T>(&mut self, name: &str, value: T)
where T: Encode,

Sets the value of the ivar of self with the given name. Panics if self has no ivar with the given name. Unsafe because the caller must ensure that the ivar is actually of type T.