#[repr(C)]pub struct NSEdgeInsets {
pub top: CGFloat,
pub left: CGFloat,
pub bottom: CGFloat,
pub right: CGFloat,
}Expand description
A description of the distance between the edges of two rectangles.
Fields
top: CGFloatThe distance from the top of the source rectangle to the top of the result rectangle.
left: CGFloatThe distance from the left side of the source rectangle to the left side of the result rectangle.
bottom: CGFloatThe distance from the bottom of the source rectangle to the bottom of the result rectangle.
right: CGFloatThe distance from the right side of the source rectangle to the right side of the result rectangle.