NSMutableDictionary

Struct NSMutableDictionary 

pub struct NSMutableDictionary<K, V> {
    pub ptr: Id<Object>,
    /* private fields */
}
A dynamic collection of objects associated with unique keys.

Fields

ptr: Id<Object>

The raw pointer to the Objective-C object.

Implementations

Source

impl<K, V> NSMutableDictionary<K, V>

pub fn new() -> Self

Creates a new empty dictionary.

pub fn with_capacity(capacity: UInt) -> Self

Creates a new dictionary with the specified capacity.

pub fn insert(&mut self, key: K, value: V)
where K: PNSObject, V: PNSObject,

Creates a new dictionary with the specified capacity and load factor.

Methods from Deref<Target = Object>

pub fn class(&self) -> &Class

Returns the class of self.

pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

Returns a reference to the ivar of self with the given name. Panics if self has no ivar with the given name. Unsafe because the caller must ensure that the ivar is actually of type T.

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

Returns a mutable reference to the ivar of self with the given name. Panics if self has no ivar with the given name. Unsafe because the caller must ensure that the ivar is actually of type T.

pub unsafe fn set_ivar<T>(&mut self, name: &str, value: T)
where T: Encode,

Sets the value of the ivar of self with the given name. Panics if self has no ivar with the given name. Unsafe because the caller must ensure that the ivar is actually of type T.