pub struct NSOperatingSystemVersion {
pub major: isize,
pub minor: isize,
pub patch_version: isize,
}Expand description
A structure that contains version information about the currently executing operating system, including major, minor, and patch version numbers.
Fields
major: isizeThe major release number, such as 10 in version 10.9.3.
minor: isizeThe minor release number, such as 9 in version 10.9.3.
patch_version: isizeThe update release number, such as 3 in version 10.9.3.