NSRange

Struct NSRange 

#[repr(C)]
pub struct NSRange { pub location: UInt, pub length: UInt, }
A structure used to describe a portion of a series, such as characters in a string or objects in an array.

Fields

location: UInt

The number of items in the range (can be 0). For type compatibility with the rest of the system, LONG_MAX is the maximum value you should use for length.

length: UInt

The start index (0 is the first, as in C arrays). For type compatibility with the rest of the system, LONG_MAX is the maximum value you should use for location.