INSEnumerator

Trait INSEnumerator 

pub trait INSEnumerator<ObjectType>: PNSObject
where ObjectType: PNSObject + FromId,
{ // Provided methods fn m_next_object(&self) -> ObjectType { ... } fn m_all_objects(&self) -> NSArray<ObjectType> { ... } }
An abstract class whose subclasses enumerate collections of objects, such as arrays and dictionaries.

Provided Methods

fn m_next_object(&self) -> ObjectType

Returns the next object from the collection being enumerated.

fn m_all_objects(&self) -> NSArray<ObjectType>

The array of unenumerated objects.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<ObjectType> INSEnumerator<ObjectType> for NSEnumerator<ObjectType>
where ObjectType: PNSObject + FromId,