INSError

Trait INSError 

pub trait INSError: PNSObject {
Show 13 methods // Provided methods fn m_error_with_domain_code_user_info( domain: NSErrorDomain, code: Int, dict: NSDictionary<NSErrorUserInfoKey, id>, ) -> Self where Self: Sized + FromId { ... } fn m_init_with_domain_code_user_info( &mut self, domain: NSErrorDomain, code: Int, dict: NSDictionary<NSErrorUserInfoKey, id>, ) -> Self where Self: Sized + FromId { ... } fn p_code(&self) -> Int { ... } fn p_domain(&self) -> NSErrorDomain { ... } fn p_user_info(&self) -> NSDictionary<NSErrorUserInfoKey, id> { ... } fn p_localized_description(&self) -> NSString { ... } fn p_localized_recovery_options(&self) -> NSArray<NSString> { ... } fn p_localized_recovery_suggestion(&self) -> NSString { ... } fn p_localized_failure_reason(&self) -> NSString { ... } fn p_recovery_attempter(&self) -> id { ... } fn m_attempt_recovery_from_error_option_index( &self, error: NSError, recovery_index: UInt, ) -> bool { ... } fn m_help_anchor(&self) -> NSString { ... } fn p_underlying_errors(&self) -> NSArray<NSError> { ... }
}
A trait containing all the methods for NSError

Provided Methods

fn m_error_with_domain_code_user_info( domain: NSErrorDomain, code: Int, dict: NSDictionary<NSErrorUserInfoKey, id>, ) -> Self
where Self: Sized + FromId,

Creates and initializes an NSError object for a given domain and code with a given userInfo dictionary.

fn m_init_with_domain_code_user_info( &mut self, domain: NSErrorDomain, code: Int, dict: NSDictionary<NSErrorUserInfoKey, id>, ) -> Self
where Self: Sized + FromId,

Returns an NSError object initialized for a given domain and code with a given userInfo dictionary.

fn p_code(&self) -> Int

The error code.

fn p_domain(&self) -> NSErrorDomain

A string containing the error domain.

fn p_user_info(&self) -> NSDictionary<NSErrorUserInfoKey, id>

The user info dictionary.

fn p_localized_description(&self) -> NSString

A string containing the localized description of the error.

fn p_localized_recovery_options(&self) -> NSArray<NSString>

An array containing the localized titles of buttons appropriate for displaying in an alert panel.

fn p_localized_recovery_suggestion(&self) -> NSString

A string containing the localized recovery suggestion for the error.

fn p_localized_failure_reason(&self) -> NSString

A string containing the localized explanation of the reason for the error.

fn p_recovery_attempter(&self) -> id

The object in the user info dictionary corresponding to the NSRecoveryAttempterErrorKey key.

fn m_attempt_recovery_from_error_option_index( &self, error: NSError, recovery_index: UInt, ) -> bool

Implemented to attempt a recovery from an error noted in an application-modal dialog.

fn m_help_anchor(&self) -> NSString

A string to display in response to an alert panel help anchor button being pressed.

fn p_underlying_errors(&self) -> NSArray<NSError>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors