INSNumberFormatter

Trait INSNumberFormatter 

pub trait INSNumberFormatter: INSFormatter {
Show 132 methods // Provided methods fn p_formatter_behavior(&self) -> NSNumberFormatterBehavior { ... } fn p_set_formatter_behavior(&mut self, behavior: NSNumberFormatterBehavior) { ... } fn m_set_default_formatter_behavior(behavior: NSNumberFormatterBehavior) { ... } fn m_default_formatter_behavior() -> NSNumberFormatterBehavior { ... } fn p_number_style(&self) -> NSNumberFormatterStyle { ... } fn p_set_number_style(&mut self, style: NSNumberFormatterStyle) { ... } fn p_generates_decimal_numbers(&self) { ... } fn m_get_object_value_for_string_range_error( &self, obj: id, string: NSString, rangep: NSRange, error: NSError, ) -> bool { ... } fn m_number_from_string(&self, string: NSString) -> NSNumber { ... } fn m_string_from_number(&self, number: NSNumber) -> NSString { ... } fn m_localized_string_from_number_number_style( num: NSNumber, nstyle: NSNumberFormatterStyle, ) -> NSString { ... } fn p_localizes_format(&self) -> bool { ... } fn p_set_localizes_format(&mut self, localizes_format: bool) { ... } fn p_locale(&self) -> NSLocale { ... } fn p_set_locale(&mut self, locale: NSLocale) { ... } fn p_rounding_behavior(&self) -> NSDecimalNumberHandler { ... } fn p_set_rounding_behavior(&mut self, behavior: NSNumberFormatterBehavior) { ... } fn p_rounding_increment(&self) -> NSNumber { ... } fn p_set_rounding_increment(&mut self, number: NSNumber) { ... } fn p_rounding_mode(&self) -> NSNumberFormatterRoundingMode { ... } fn p_set_rounding_mode(&mut self, mode: NSNumberFormatterRoundingMode) { ... } fn p_minimum_integer_digits(&self) -> UInt { ... } fn p_set_minimum_integer_digits(&mut self, min: UInt) { ... } fn p_maximum_integer_digits(&self) -> UInt { ... } fn p_set_maximum_integer_digits(&mut self, max: UInt) { ... } fn p_minimum_fraction_digits(&self) -> UInt { ... } fn p_set_minimum_fraction_digits(&mut self, min: UInt) { ... } fn p_maximum_fraction_digits(&self) -> UInt { ... } fn p_set_maximum_fraction_digits(&mut self, max: UInt) { ... } fn p_uses_significant_digits(&self) -> bool { ... } fn p_set_uses_significant_digits(&mut self, uses: bool) { ... } fn p_minimum_significant_digits(&self) -> UInt { ... } fn p_set_minimum_significant_digits(&self, min: UInt) { ... } fn p_maximum_significant_digits(&self) -> UInt { ... } fn p_set_maximum_significant_digits(&self, max: UInt) { ... } fn p_format(&self) -> NSString { ... } fn p_set_format(&mut self, format: NSString) { ... } fn p_formatting_context(&self) -> NSFormattingContext { ... } fn p_set_formatting_context(&mut self, context: NSFormattingContext) { ... } fn p_format_width(&self) -> UInt { ... } fn p_set_format_width(&mut self, width: UInt) { ... } fn p_negative_format(&self) -> NSString { ... } fn p_set_negative_format(&mut self) { ... } fn p_positive_format(&self) -> NSString { ... } fn p_set_positive_format(&mut self, format: NSString) { ... } fn p_multiplier(&self) -> NSNumber { ... } fn p_set_multiplier(&mut self, multiplier: NSNumber) { ... } fn p_percent_symbol(&self) -> NSString { ... } fn p_set_percent_symbol(&mut self, symbol: NSString) { ... } fn p_per_mill_symbol(&self) -> NSString { ... } fn p_set_per_mill_symbol(&mut self, symbol: NSString) { ... } fn p_minus_sign(&self) -> NSString { ... } fn p_set_minus_sign(&mut self, sign: NSString) { ... } fn p_plus_sign(&self) -> NSString { ... } fn p_set_plus_sign(&mut self, sign: NSString) { ... } fn p_exponent_symbol(&self) -> NSString { ... } fn p_set_exponent_symbol(&mut self, sign: NSString) { ... } fn p_zero_symbol(&self) -> NSString { ... } fn p_set_zero_symbol(&mut self, sign: NSString) { ... } fn p_nil_symbol(&self) -> NSString { ... } fn p_set_nil_symbol(&mut self, sign: NSString) { ... } fn p_not_a_number_symbol(&self) -> NSString { ... } fn p_set_not_a_number_symbol(&mut self, symbol: NSString) { ... } fn p_negative_infinity_symbol(&self) -> NSString { ... } fn p_set_negative_infinity_symbol(&self, symbol: NSString) { ... } fn p_positive_infinity_symbol(&self) -> NSString { ... } fn p_set_positive_infinity_symbol(&self, symbol: NSString) { ... } fn p_currency_symbol(&self) -> NSString { ... } fn p_set_currency_symbol(&mut self, symbol: NSString) { ... } fn p_currency_code(&self) -> NSString { ... } fn p_set_currency_code(&mut self, code: NSString) { ... } fn p_international_currency_symbol(&self) -> NSString { ... } fn p_set_international_currency_symbol(&mut self, symbol: NSString) { ... } fn p_currency_grouping_separator(&self) -> NSString { ... } fn p_positive_prefix(&self) -> NSString { ... } fn p_set_positive_prefix(&mut self, prefix: NSString) { ... } fn p_positive_suffix(&self) -> NSString { ... } fn p_set_positive_suffix(&mut self, suffix: NSString) { ... } fn p_negative_prefix(&self) -> NSString { ... } fn p_set_negative_prefix(&mut self, prefix: NSString) { ... } fn p_negative_suffix(&self) -> NSString { ... } fn p_text_attributes_for_negative_values( &self, ) -> NSDictionary<NSString, id> { ... } fn p_set_text_attributes_for_negative_values( &mut self, attributes: NSDictionary<NSString, id>, ) { ... } fn p_text_attributes_for_positive_values( &self, ) -> NSDictionary<NSString, id> { ... } fn p_set_text_attributes_for_positive_values( &mut self, attributes: NSDictionary<NSString, id>, ) { ... } fn p_attributed_string_for_zero(&self) -> NSAttributedString { ... } fn p_set_attributed_string_for_zero(&mut self, string: NSAttributedString) { ... } fn p_text_attributes_for_zero(&self) -> NSDictionary<NSString, id> { ... } fn p_set_text_attributes_for_zero( &mut self, attributes: NSDictionary<NSString, id>, ) { ... } fn p_attributed_string_for_nil(&self) -> NSAttributedString { ... } fn p_set_attributed_string_for_nil(&mut self, string: NSAttributedString) { ... } fn p_text_attributes_for_nil(&self) -> NSDictionary<NSString, id> { ... } fn p_set_text_attributes_for_nil( &mut self, attributes: NSDictionary<NSString, id>, ) { ... } fn p_attributed_string_for_not_a_number(&self) -> NSAttributedString { ... } fn p_set_attributed_string_for_not_a_number( &mut self, string: NSAttributedString, ) { ... } fn p_text_attributes_for_not_a_number(&self) -> NSDictionary<NSString, id> { ... } fn p_set_text_attributes_for_not_a_number( &mut self, attributes: NSDictionary<NSString, id>, ) { ... } fn p_text_attributes_for_positive_infinity( &self, ) -> NSDictionary<NSString, id> { ... } fn p_set_text_attributes_for_positive_infinity( &mut self, attributes: NSDictionary<NSString, id>, ) { ... } fn p_text_attributes_for_negative_infinity( &self, ) -> NSDictionary<NSString, id> { ... } fn p_set_text_attributes_for_negative_infinity( &mut self, attributes: NSDictionary<NSString, id>, ) { ... } fn p_grouping_separator(&self) -> NSString { ... } fn p_set_grouping_separator(&mut self, separator: NSString) { ... } fn p_uses_grouping_separator(&self) -> bool { ... } fn p_set_uses_grouping_separator(&mut self, flag: bool) { ... } fn p_thousand_separator(&self) -> NSString { ... } fn p_set_thousand_separator(&mut self, separator: NSString) { ... } fn p_uses_thousand_separators(&self) -> bool { ... } fn p_set_uses_thousand_separators(&mut self, flag: bool) { ... } fn p_decimal_separator(&self) -> NSString { ... } fn p_always_show_decimal_separator(&self) -> bool { ... } fn p_set_always_show_decimal_separator(&mut self, flag: bool) { ... } fn p_currency_decimal_separator(&self) -> NSString { ... } fn p_set_currency_decimal_separator(&mut self, separator: NSString) { ... } fn p_grouping_size(&self) -> Int { ... } fn p_set_grouping_size(&mut self, size: Int) { ... } fn p_secondary_grouping_size(&self) -> Int { ... } fn p_set_secondary_grouping_size(&mut self, size: Int) { ... } fn p_padding_character(&self) -> NSString { ... } fn p_set_padding_character(&mut self, padding: NSString) { ... } fn p_padding_position(&self) -> NSNumberFormatterPadPosition { ... } fn p_set_padding_position(&mut self, position: NSNumberFormatterPadPosition) { ... } fn p_allows_floats(&self) -> bool { ... } fn p_set_allows_floats(&mut self, flag: bool) { ... } fn p_minimum(&self) -> NSNumber { ... } fn p_set_minimum(&mut self, number: NSNumber) { ... } fn p_maximum(&self) -> NSNumber { ... } fn p_set_maximum(&mut self, number: NSNumber) { ... } fn p_lenient(&self) -> bool { ... } fn p_set_lenient(&mut self, flag: bool) { ... } fn p_partial_string_validation_enabled(&self) -> bool { ... } fn p_set_partial_string_validation_enabled(&mut self, flag: bool) { ... }
}
A trait containing all the methods for NSNumberFormatter

Provided Methods

fn p_formatter_behavior(&self) -> NSNumberFormatterBehavior

The formatter behavior of the receiver.

fn p_set_formatter_behavior(&mut self, behavior: NSNumberFormatterBehavior)

The formatter behavior of the receiver.

fn m_set_default_formatter_behavior(behavior: NSNumberFormatterBehavior)

Sets the default formatter behavior for new instances of NSNumberFormatter.

fn m_default_formatter_behavior() -> NSNumberFormatterBehavior

Returns an NSNumberFormatterBehavior constant that indicates default formatter behavior for new instances of NSNumberFormatter.

fn p_number_style(&self) -> NSNumberFormatterStyle

The number style used by the receiver.

fn p_set_number_style(&mut self, style: NSNumberFormatterStyle)

The number style used by the receiver.

fn p_generates_decimal_numbers(&self)

Determines whether the receiver creates instances of super::NSDecimalNumber when it converts strings to number objects.

fn m_get_object_value_for_string_range_error( &self, obj: id, string: NSString, rangep: NSRange, error: NSError, ) -> bool

Returns by reference a cell-content object after creating it from a range of characters in a given string.

fn m_number_from_string(&self, string: NSString) -> NSNumber

Returns an NSNumber object created by parsing a given string.

fn m_string_from_number(&self, number: NSNumber) -> NSString

Returns a string containing the formatted value of the provided number object.

fn m_localized_string_from_number_number_style( num: NSNumber, nstyle: NSNumberFormatterStyle, ) -> NSString

Returns a localized number string with the specified style.

fn p_localizes_format(&self) -> bool

Determines whether the dollar sign character ($), decimal separator character (.), and thousand separator character (,) are converted to appropriately localized characters as specified by the user’s localization preference.

fn p_set_localizes_format(&mut self, localizes_format: bool)

Sets whether the dollar sign character ($), decimal separator character (.), and thousand separator character (,) are converted to appropriately localized characters as specified by the user’s localization preference.

fn p_locale(&self) -> NSLocale

The locale of the receiver.

fn p_set_locale(&mut self, locale: NSLocale)

Sets the locale of the receiver.

fn p_rounding_behavior(&self) -> NSDecimalNumberHandler

The rounding behavior used by the receiver.

fn p_set_rounding_behavior(&mut self, behavior: NSNumberFormatterBehavior)

Set the rounding behavior used by the receiver.

fn p_rounding_increment(&self) -> NSNumber

The rounding increment used by the receiver.

fn p_set_rounding_increment(&mut self, number: NSNumber)

The rounding increment used by the receiver.

fn p_rounding_mode(&self) -> NSNumberFormatterRoundingMode

The rounding mode used by the receiver.

fn p_set_rounding_mode(&mut self, mode: NSNumberFormatterRoundingMode)

The rounding mode used by the receiver.

fn p_minimum_integer_digits(&self) -> UInt

The minimum number of digits before the decimal separator.

fn p_set_minimum_integer_digits(&mut self, min: UInt)

Sets the minimum number of digits before the decimal separator.

Example
use rust_macios::objective_c_runtime::traits::PNSObject;
use rust_macios::foundation::NSNumberFormatter;

let mut number_formatter = NSNumberFormatter::m_new();

number_formatter.set_minimum_integer_digits(0); // default
assert_eq!(number_formatter.string_from_number(123.into()), "123");

number_formatter.set_minimum_integer_digits(5);
assert_eq!(number_formatter.string_from_number(123.into()), "00123");
fn p_maximum_integer_digits(&self) -> UInt

The maximum number of digits before the decimal separator.

fn p_set_maximum_integer_digits(&mut self, max: UInt)

The maximum number of digits before the decimal separator.

Example
use rust_macios::objective_c_runtime::traits::PNSObject;
use rust_macios::foundation::NSNumberFormatter;

let mut number_formatter = NSNumberFormatter::m_new();

number_formatter.set_maximum_integer_digits(42); // default
assert_eq!(number_formatter.string_from_number(12345.into()), "12345");

number_formatter.set_maximum_integer_digits(3);
assert_eq!(number_formatter.string_from_number(12345.into()), "345");
fn p_minimum_fraction_digits(&self) -> UInt

The minimum number of digits after the decimal separator.

fn p_set_minimum_fraction_digits(&mut self, min: UInt)

Sets the minimum number of digits after the decimal separator.

Example
use rust_macios::objective_c_runtime::traits::PNSObject;
use rust_macios::foundation::NSNumberFormatter;

let mut number_formatter = NSNumberFormatter::m_new();

number_formatter.set_minimum_fraction_digits(0); // default
assert_eq!(number_formatter.string_from_number(123.456.into()), "123");

number_formatter.set_minimum_fraction_digits(5);
assert_eq!(number_formatter.string_from_number(123.456.into()), "123.45600");
fn p_maximum_fraction_digits(&self) -> UInt

The maximum number of digits after the decimal separator.

fn p_set_maximum_fraction_digits(&mut self, max: UInt)

Sets the maximum number of digits after the decimal separator.

Example
use rust_macios::objective_c_runtime::traits::PNSObject;
use rust_macios::foundation::NSNumberFormatter;

let mut number_formatter = NSNumberFormatter::m_new();

number_formatter.set_maximum_fraction_digits(0); // default
assert_eq!(number_formatter.string_from_number(123.456.into()), "123");

number_formatter.set_maximum_fraction_digits(3);
assert_eq!(number_formatter.string_from_number(123.456789.into()), "123.457");
fn p_uses_significant_digits(&self) -> bool

A Boolean value indicating whether the formatter uses minimum and maximum significant digits when formatting numbers.

fn p_set_uses_significant_digits(&mut self, uses: bool)

A Boolean value indicating whether the formatter uses minimum and maximum significant digits when formatting numbers.

Example
use rust_macios::objective_c_runtime::traits::PNSObject;
use rust_macios::foundation::NSNumberFormatter;

let mut number_formatter = NSNumberFormatter::m_new();

// Using significant digits
number_formatter.set_uses_significant_digits(true);
assert_eq!(number_formatter.string_from_number(12345678.into()), "12345700");
assert_eq!(number_formatter.string_from_number(1234.5678.into()), "1234.57");
assert_eq!(number_formatter.string_from_number(100.2345678.into()), "100.235");
assert_eq!(number_formatter.string_from_number(1.230000.into()), "1.23");
assert_eq!(number_formatter.string_from_number(0.00000123.into()), "0.00000123");

// Using integer and fraction digits
number_formatter.set_uses_significant_digits(false);
assert_eq!(number_formatter.string_from_number(12345678.into()), "12345678");
assert_eq!(number_formatter.string_from_number(1234.5678.into()), "1235");
assert_eq!(number_formatter.string_from_number(100.2345678.into()), "100");
assert_eq!(number_formatter.string_from_number(1.230000.into()), "1");
assert_eq!(number_formatter.string_from_number(0.00000123.into()), "0");
fn p_minimum_significant_digits(&self) -> UInt

The minimum number of significant digits for the number formatter.

fn p_set_minimum_significant_digits(&self, min: UInt)

Sets the minimum number of significant digits for the number formatter.

fn p_maximum_significant_digits(&self) -> UInt

The maximum number of significant digits for the number formatter.

fn p_set_maximum_significant_digits(&self, max: UInt)

Sets the maximum number of significant digits for the number formatter.

fn p_format(&self) -> NSString

The receiver’s format.

fn p_set_format(&mut self, format: NSString)

Sets the receiver’s format.

fn p_formatting_context(&self) -> NSFormattingContext

The capitalization formatting context used when formatting a number.

fn p_set_formatting_context(&mut self, context: NSFormattingContext)

Sets the capitalization formatting context used when formatting a number.

fn p_format_width(&self) -> UInt

The format width used by the receiver.

fn p_set_format_width(&mut self, width: UInt)

Sets the format width used by the receiver.

fn p_negative_format(&self) -> NSString

The format the receiver uses to display negative values.

fn p_set_negative_format(&mut self)

Sets the format the receiver uses to display negative values.

fn p_positive_format(&self) -> NSString

The format the receiver uses to display positive values.

fn p_set_positive_format(&mut self, format: NSString)

Sets the format the receiver uses to display positive values.

fn p_multiplier(&self) -> NSNumber

The multiplier of the receiver.

fn p_set_multiplier(&mut self, multiplier: NSNumber)

Sets the multiplier of the receiver.

fn p_percent_symbol(&self) -> NSString

The string used to represent a percent symbol.

fn p_set_percent_symbol(&mut self, symbol: NSString)

Sets the string used to represent a percent symbol.

fn p_per_mill_symbol(&self) -> NSString

The string used to represent a per-mill (per-thousand) symbol.

fn p_set_per_mill_symbol(&mut self, symbol: NSString)

The string used to represent a per-mill (per-thousand) symbol.

fn p_minus_sign(&self) -> NSString

The string used to represent a minus sign.

fn p_set_minus_sign(&mut self, sign: NSString)

Sets the string used to represent a minus sign.

fn p_plus_sign(&self) -> NSString

The string used to represent a plus sign.

fn p_set_plus_sign(&mut self, sign: NSString)

Sets the string used to represent a plus sign.

fn p_exponent_symbol(&self) -> NSString

The string used to represent an exponent symbol.

fn p_set_exponent_symbol(&mut self, sign: NSString)

Sets the string used to represent an exponent symbol.

fn p_zero_symbol(&self) -> NSString

The string used to represent a zero symbol.

fn p_set_zero_symbol(&mut self, sign: NSString)

Sets the string used to represent a zero symbol.

fn p_nil_symbol(&self) -> NSString

The string used to represent a nil symbol.

fn p_set_nil_symbol(&mut self, sign: NSString)

Sets the string used to represent a nil symbol.

fn p_not_a_number_symbol(&self) -> NSString

The string used to represent a NaN (“not a number”) value.

fn p_set_not_a_number_symbol(&mut self, symbol: NSString)

Sets the string used to represent a NaN (“not a number”) value.

fn p_negative_infinity_symbol(&self) -> NSString

The string used to represent a negative infinity symbol.

fn p_set_negative_infinity_symbol(&self, symbol: NSString)

Sets the string used to represent a negative infinity symbol.

fn p_positive_infinity_symbol(&self) -> NSString

The string used to represent a positive infinity symbol.

fn p_set_positive_infinity_symbol(&self, symbol: NSString)

Sets the string used to represent a positive infinity symbol.

fn p_currency_symbol(&self) -> NSString

The string used by the receiver as a local currency symbol.

fn p_set_currency_symbol(&mut self, symbol: NSString)

Sets the string used by the receiver as a local currency symbol.

fn p_currency_code(&self) -> NSString

The receiver’s currency code.

fn p_set_currency_code(&mut self, code: NSString)

Sets the receiver’s currency code.

fn p_international_currency_symbol(&self) -> NSString

The international currency symbol used by the receiver.

fn p_set_international_currency_symbol(&mut self, symbol: NSString)

Sets the international currency symbol used by the receiver.

fn p_currency_grouping_separator(&self) -> NSString

The currency grouping separator for the receiver.

fn p_positive_prefix(&self) -> NSString

The string the receiver uses as the prefix for positive values.

fn p_set_positive_prefix(&mut self, prefix: NSString)

Sets the string the receiver uses as the prefix for positive values.

fn p_positive_suffix(&self) -> NSString

The string the receiver uses as the suffix for positive values.

fn p_set_positive_suffix(&mut self, suffix: NSString)

Sets the string the receiver uses as the suffix for positive values.

fn p_negative_prefix(&self) -> NSString

The string the receiver uses as a prefix for negative values.

fn p_set_negative_prefix(&mut self, prefix: NSString)

Sets the string the receiver uses as a prefix for negative values.

fn p_negative_suffix(&self) -> NSString

The string the receiver uses as a suffix for negative values.

fn p_text_attributes_for_negative_values(&self) -> NSDictionary<NSString, id>

The text attributes to be used in displaying negative values.

fn p_set_text_attributes_for_negative_values( &mut self, attributes: NSDictionary<NSString, id>, )

Sets the text attributes to be used in displaying negative values.

fn p_text_attributes_for_positive_values(&self) -> NSDictionary<NSString, id>

The text attributes to be used in displaying positive values.

fn p_set_text_attributes_for_positive_values( &mut self, attributes: NSDictionary<NSString, id>, )

Sets the text attributes to be used in displaying positive values.

fn p_attributed_string_for_zero(&self) -> NSAttributedString

The attributed string that the receiver uses to display zero values.

fn p_set_attributed_string_for_zero(&mut self, string: NSAttributedString)

Sets the attributed string that the receiver uses to display zero values.

fn p_text_attributes_for_zero(&self) -> NSDictionary<NSString, id>

The text attributes used to display a zero value.

fn p_set_text_attributes_for_zero( &mut self, attributes: NSDictionary<NSString, id>, )

Sets the text attributes used to display a zero value.

fn p_attributed_string_for_nil(&self) -> NSAttributedString

The attributed string the receiver uses to display nil values.

fn p_set_attributed_string_for_nil(&mut self, string: NSAttributedString)

Sets the attributed string the receiver uses to display nil values.

fn p_text_attributes_for_nil(&self) -> NSDictionary<NSString, id>

The text attributes used to display the nil symbol.

fn p_set_text_attributes_for_nil( &mut self, attributes: NSDictionary<NSString, id>, )

Sets the text attributes used to display the nil symbol.

fn p_attributed_string_for_not_a_number(&self) -> NSAttributedString

The attributed string the receiver uses to display “not a number” values.

fn p_set_attributed_string_for_not_a_number( &mut self, string: NSAttributedString, )

Sets the attributed string the receiver uses to display “not a number” values.

fn p_text_attributes_for_not_a_number(&self) -> NSDictionary<NSString, id>

The text attributes used to display the NaN (“not a number”) string.

fn p_set_text_attributes_for_not_a_number( &mut self, attributes: NSDictionary<NSString, id>, )

Sets the text attributes used to display the NaN (“not a number”) string.

fn p_text_attributes_for_positive_infinity(&self) -> NSDictionary<NSString, id>

The text attributes used to display the positive infinity symbol.

fn p_set_text_attributes_for_positive_infinity( &mut self, attributes: NSDictionary<NSString, id>, )

Sets the text attributes used to display the positive infinity symbol.

fn p_text_attributes_for_negative_infinity(&self) -> NSDictionary<NSString, id>

The text attributes used to display the negative infinity symbol.

fn p_set_text_attributes_for_negative_infinity( &mut self, attributes: NSDictionary<NSString, id>, )

Sets the text attributes used to display the negative infinity symbol.

fn p_grouping_separator(&self) -> NSString

The string used by the receiver for a grouping separator.

fn p_set_grouping_separator(&mut self, separator: NSString)

Sets the string used by the receiver for a grouping separator.

fn p_uses_grouping_separator(&self) -> bool

Determines whether the receiver displays the group separator.

fn p_set_uses_grouping_separator(&mut self, flag: bool)

Sets whether the receiver displays the group separator.

fn p_thousand_separator(&self) -> NSString

The character the receiver uses as a thousand separator.

fn p_set_thousand_separator(&mut self, separator: NSString)

Sets the character the receiver uses as a thousand separator.

fn p_uses_thousand_separators(&self) -> bool

Determines whether the receiver uses thousand separators.

fn p_set_uses_thousand_separators(&mut self, flag: bool)

Sets whether the receiver uses thousand separators.

fn p_decimal_separator(&self) -> NSString

The character the receiver uses as a decimal separator.

fn p_always_show_decimal_separator(&self) -> bool

Determines whether the receiver always shows the decimal separator, even for integer numbers.

fn p_set_always_show_decimal_separator(&mut self, flag: bool)

Sets whether the receiver always shows the decimal separator, even for integer numbers.

fn p_currency_decimal_separator(&self) -> NSString

The string used by the receiver as a currency decimal separator.

fn p_set_currency_decimal_separator(&mut self, separator: NSString)

Sets the string used by the receiver as a currency decimal separator.

fn p_grouping_size(&self) -> Int

The grouping size of the receiver.

fn p_set_grouping_size(&mut self, size: Int)

Sets the grouping size of the receiver.

fn p_secondary_grouping_size(&self) -> Int

The secondary grouping size of the receiver.

fn p_set_secondary_grouping_size(&mut self, size: Int)

Sets the secondary grouping size of the receiver.

fn p_padding_character(&self) -> NSString

The string that the receiver uses to pad numbers in the formatted string representation.

fn p_set_padding_character(&mut self, padding: NSString)

Sets the string that the receiver uses to pad numbers in the formatted string representation.

fn p_padding_position(&self) -> NSNumberFormatterPadPosition

The padding position used by the receiver.

fn p_set_padding_position(&mut self, position: NSNumberFormatterPadPosition)

Sets the padding position used by the receiver.

fn p_allows_floats(&self) -> bool

Determines whether the receiver allows as input floating-point values (that is, values that include the period character [.]).

fn p_set_allows_floats(&mut self, flag: bool)

Sets whether the receiver allows as input floating-point values (that is, values that include the period character [.]).

fn p_minimum(&self) -> NSNumber

The lowest number allowed as input by the receiver.

fn p_set_minimum(&mut self, number: NSNumber)

Sets the lowest number allowed as input by the receiver.

fn p_maximum(&self) -> NSNumber

The highest number allowed as input by the receiver.

fn p_set_maximum(&mut self, number: NSNumber)

Sets the highest number allowed as input by the receiver.

fn p_lenient(&self) -> bool

Determines whether the receiver will use heuristics to guess at the number which is intended by a string.

fn p_set_lenient(&mut self, flag: bool)

Sets whether the receiver will use heuristics to guess at the number which is intended by a string.

fn p_partial_string_validation_enabled(&self) -> bool

Determines whether partial string validation is enabled for the receiver.

fn p_set_partial_string_validation_enabled(&mut self, flag: bool)

Sets whether partial string validation is enabled for the receiver.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors