pub type NSRect = CGRect;Expand description
A rectangle.
Aliased Type
#[repr(C)]pub struct NSRect {
pub origin: CGPoint,
pub size: CGSize,
}Fields
origin: CGPointA point that specifies the coordinates of the rectangle’s origin.
size: CGSizeA size that specifies the height and width of the rectangle.