#[repr(i64)]pub enum NLDistanceType {
Cosine = 0,
}Expand description
The means of calculating a distance between two locations in a text embedding.
Variants
Cosine = 0
A method of calculating distance by using cosine similarity.