#[repr(u64)]pub enum NLTaggerOptions {
OmitWords = 1,
OmitPunctuation = 2,
OmitWhitespace = 4,
OmitOther = 8,
JoinNames = 16,
JoinContractions = 32,
}Expand description
Constants for linguistic tagger enumeration specifying which tokens to omit and whether to join names.
Variants
OmitWords = 1
Omit tokens of type word (items considered to be words).
OmitPunctuation = 2
Omit tokens of type punctuation (all punctuation).
OmitWhitespace = 4
Omit tokens of type whitespace (whitespace of all sorts).
OmitOther = 8
Omit tokens of type other (non-linguistic items, such as symbols).
JoinNames = 16
Typically, multiple-word names will be returned as multiple tokens, following the standard tokenization practice of the tagger.
JoinContractions = 32
Contractions will be returned as one token.