INLModelConfiguration

Trait INLModelConfiguration 

pub trait INLModelConfiguration: PNSObject {
    // Provided methods
    fn p_language(&self) -> Option<NLLanguage> { ... }
    fn p_revision(&self) -> UInt { ... }
    fn m_supported_revisions_for_type(type: NLModelType) -> NSIndexSet { ... }
    fn m_current_revision_for_type(type: NLModelType) -> UInt { ... }
    fn p_ml_type(&self) -> NLModelType { ... }
}
A trait containing all the methods for NLModelConfiguration

Provided Methods

fn p_language(&self) -> Option<NLLanguage>

The language the model supports.

fn p_revision(&self) -> UInt

The version of the Natural Language framework that trained the model.

fn m_supported_revisions_for_type(type: NLModelType) -> NSIndexSet

Returns the versions of the Natural Language framework the OS supports.

fn m_current_revision_for_type(type: NLModelType) -> UInt

Returns the current Natural Language framework version in the OS.

fn p_ml_type(&self) -> NLModelType

The natural language model type of the model.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors