Module traits

Module traits 

Traits for the Objective-C runtime.

Traits

FromId
Converting an Objective-C pointer to Object
INSObject
The group of methods that are fundamental to all Objective-C objects.
PNSObject
The group of methods that are fundamental to all Objective-C objects.
ToId
Converting Object to an Objective-C pointer