IUNCalendarNotificationTrigger

Trait IUNCalendarNotificationTrigger 

pub trait IUNCalendarNotificationTrigger: IUNNotificationTrigger {
    // Provided methods
    fn m_trigger_with_date_matching_components_repeats(
        date_components: NSDateComponents,
        repeats: bool,
    ) -> Self
       where Self: Sized + FromId { ... }
    fn m_next_trigger_date(&self) -> Option<NSDate> { ... }
    fn p_date_components(&self) -> NSDateComponents { ... }
}
A trait containing all the methods for UNCalendarNotificationTrigger

Provided Methods

fn m_trigger_with_date_matching_components_repeats( date_components: NSDateComponents, repeats: bool, ) -> Self
where Self: Sized + FromId,

Creates a calendar trigger using the date components parameter.

fn m_next_trigger_date(&self) -> Option<NSDate>

The next date at which the trigger conditions are met.

fn p_date_components(&self) -> NSDateComponents

The date components to construct this object.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors