IUNNotificationAction

Trait IUNNotificationAction 

pub trait IUNNotificationAction: PNSObject {
    // Provided methods
    fn m_action_with_identifier_title_options(
        identifier: NSString,
        title: NSString,
        options: &[UNNotificationActionOptions],
    ) -> Self
       where Self: Sized + FromId { ... }
    fn m_action_with_identifier_title_options_icon(
        identifier: NSString,
        title: NSString,
        options: &[UNNotificationActionOptions],
        icon: UNNotificationActionIcon,
    ) -> Self
       where Self: Sized + FromId { ... }
    fn p_identifier(&self) -> NSString { ... }
    fn p_title(&self) -> NSString { ... }
    fn p_icon(&self) -> Option<UNNotificationActionIcon> { ... }
    fn p_options(&self) -> UNNotificationActionOptions { ... }
}
A trait containing all the methods for UNNotificationAction

Provided Methods

fn m_action_with_identifier_title_options( identifier: NSString, title: NSString, options: &[UNNotificationActionOptions], ) -> Self
where Self: Sized + FromId,

Creates an action object by using the specified title and options.

fn m_action_with_identifier_title_options_icon( identifier: NSString, title: NSString, options: &[UNNotificationActionOptions], icon: UNNotificationActionIcon, ) -> Self
where Self: Sized + FromId,

fn p_identifier(&self) -> NSString

The unique string that your app uses to identify the action.

fn p_title(&self) -> NSString

The localized string to use as the title of the action.

fn p_icon(&self) -> Option<UNNotificationActionIcon>

The icon associated with the action.

fn p_options(&self) -> UNNotificationActionOptions

The behaviors associated with the action.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors