pub trait IUNNotificationContent: PNSObject {
Show 17 methods
// Provided methods
fn p_title(&self) -> NSString { ... }
fn p_subtitle(&self) -> NSString { ... }
fn p_body(&self) -> NSString { ... }
fn p_attachments(&self) -> NSArray<UNNotificationAttachment> { ... }
fn p_user_info(&self) -> NSDictionary<id, id> { ... }
fn p_launch_image_name(&self) -> NSString { ... }
fn p_badge(&self) -> Option<NSNumber> { ... }
fn p_target_content_identifier(&self) -> Option<NSString> { ... }
fn p_sound(&self) -> Option<UNNotificationSound> { ... }
fn p_interruption_level(&self) -> UNNotificationInterruptionLevel { ... }
fn p_relevance_score(&self) -> c_double { ... }
fn p_filter_criteria(&self) -> Option<NSString> { ... }
fn p_thread_identifier(&self) -> NSString { ... }
fn p_category_identifier(&self) -> NSString { ... }
fn p_summary_argument(&self) -> NSString { ... }
fn p_summary_argument_count(&self) -> UInt { ... }
fn m_content_by_updating_with_provider(
&mut self,
provider: id,
) -> Result<UNNotificationContent, NSError> { ... }
}Expand description
A trait containing all the methods for UNNotificationContent
Provided Methods
Sourcefn p_title(&self) -> NSString
fn p_title(&self) -> NSString
The localized text that provides the notification’s primary description.
Sourcefn p_subtitle(&self) -> NSString
fn p_subtitle(&self) -> NSString
The localized text that provides the notification’s secondary description.
Sourcefn p_attachments(&self) -> NSArray<UNNotificationAttachment>
fn p_attachments(&self) -> NSArray<UNNotificationAttachment>
The visual and audio attachments to display alongside the notification’s main content.
Sourcefn p_user_info(&self) -> NSDictionary<id, id>
fn p_user_info(&self) -> NSDictionary<id, id>
The custom data to associate with the notification.
Sourcefn p_launch_image_name(&self) -> NSString
fn p_launch_image_name(&self) -> NSString
The name of the image or storyboard to use when your app launches because of the notification.
Sourcefn p_target_content_identifier(&self) -> Option<NSString>
fn p_target_content_identifier(&self) -> Option<NSString>
The value your app uses to determine which scene to display to handle the notification.
Sourcefn p_sound(&self) -> Option<UNNotificationSound>
fn p_sound(&self) -> Option<UNNotificationSound>
The sound that plays when the system delivers the notification.
Sourcefn p_interruption_level(&self) -> UNNotificationInterruptionLevel
fn p_interruption_level(&self) -> UNNotificationInterruptionLevel
The notification’s importance and required delivery timing.
Sourcefn p_relevance_score(&self) -> c_double
fn p_relevance_score(&self) -> c_double
The score the system uses to determine if the notification is the summary’s featured notification.
Sourcefn p_filter_criteria(&self) -> Option<NSString>
fn p_filter_criteria(&self) -> Option<NSString>
The criteria the system evaluates to determine if it displays the notification in the current Focus.
Sourcefn p_thread_identifier(&self) -> NSString
fn p_thread_identifier(&self) -> NSString
The identifier that groups related notifications.
Sourcefn p_category_identifier(&self) -> NSString
fn p_category_identifier(&self) -> NSString
The identifier of the notification’s category.
Sourcefn p_summary_argument(&self) -> NSString
fn p_summary_argument(&self) -> NSString
The text the system adds to the notification summary to provide additional context.
Sourcefn p_summary_argument_count(&self) -> UInt
fn p_summary_argument_count(&self) -> UInt
The number the system adds to the notification summary when the notification represents multiple items.
Sourcefn m_content_by_updating_with_provider(
&mut self,
provider: id,
) -> Result<UNNotificationContent, NSError>
fn m_content_by_updating_with_provider( &mut self, provider: id, ) -> Result<UNNotificationContent, NSError>
Returns a copy of the notification that includes content from the specified provider.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".