IUNNotificationServiceExtension

Trait IUNNotificationServiceExtension 

pub trait IUNNotificationServiceExtension: PNSObject {
    // Provided methods
    fn m_did_receive_notification_request_with_content_handler<F>(
        &self,
        request: UNNotificationRequest,
        content_handler: F,
    )
       where F: IntoConcreteBlock<(UNNotificationContent,)> + 'static { ... }
    fn m_service_extension_time_will_expire(&self) { ... }
}
A trait containing all the methods for UNNotificationServiceExtension

Provided Methods

fn m_did_receive_notification_request_with_content_handler<F>( &self, request: UNNotificationRequest, content_handler: F, )

Asks you to make any needed changes to the notification and notify the system when you’re done.

fn m_service_extension_time_will_expire(&self)

Tells you that the system is terminating your extension.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors