IUNTimeIntervalNotificationTrigger

Trait IUNTimeIntervalNotificationTrigger 

pub trait IUNTimeIntervalNotificationTrigger: IUNNotificationTrigger {
    // Provided methods
    fn m_trigger_with_time_interval_repeats(
        time_interval: NSTimeInterval,
        repeats: bool,
    ) -> Self
       where Self: Sized + FromId { ... }
    fn m_next_trigger_date(&self) -> Option<NSDate> { ... }
    fn p_time_interval(&self) -> NSTimeInterval { ... }
}
A trait containing all the methods for UNTimeIntervalNotificationTrigger

Provided Methods

fn m_trigger_with_time_interval_repeats( time_interval: NSTimeInterval, repeats: bool, ) -> Self
where Self: Sized + FromId,

Creates a time interval trigger using the time value parameter.

fn m_next_trigger_date(&self) -> Option<NSDate>

The next date at which the trigger conditions are met.

fn p_time_interval(&self) -> NSTimeInterval

The time interval to create the trigger.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors