#[repr(i64)]pub enum NSTitlebarSeparatorStyle {
Automatic = 0,
None = 1,
Line = 2,
Shadow = 3,
}Expand description
Styles that determine the type of separator displayed between the title bar and content of a window.
Variants
Automatic = 0
A style indicating that the system determines the type of separator.
None = 1
A style indicating that there’s no title bar separator.
Line = 2
A style indicating that there’s no title bar separator.
Shadow = 3
A style indicating that the title bar separator is a shadow.