NSNib

Struct NSNib 

#[repr(C)]
pub struct NSNib { pub ptr: Id<Object>, }
An object that manages an app’s menus.

Fields

ptr: Id<Object>

The raw pointer to the Objective-C object.

Implementations

Source

impl NSNib

pub fn init_with_contents_of_url(&mut self, nib_file_url: NSURL) -> id

👎Deprecated: use [init_with_nib_data_bundle] instead.

Returns an NSNib object initialized to the nib file at the specified URL.

pub fn init_with_nib_named_bundle( &mut self, nib_name: NSNibName, bundle: &NSBundle, ) -> Self
where Self: Sized + FromId,

Returns an NSNib object initialized to the nib file in the specified bundle.

pub fn init_with_nib_data_bundle( &mut self, nib_data: &NSData, bundle: &NSBundle, ) -> Self
where Self: Sized + FromId,

Initializes an instance with nib data and specified bundle for locating resources.

pub fn instantiate_nib_with_owner_top_level_objects<T>( &mut self, owner: id, top_lvl_objects: &NSArray<T>, ) -> bool

👎Deprecated: use [instantiate_with_owner_top_level_objects] instead.

Unarchives and instantiates the in-memory contents of the receiver’s nib file, creating a distinct object tree and set of top level objects.

pub fn instantiate_nib_with_external_name_table<K, V>( &self, external_name_table: &NSDictionary<K, V>, ) -> bool

👎Deprecated: use [instantiate_with_owner_top_level_objects] instead.

Unarchives and instantiates the in-memory contents of the receiver’s nib file, creating a distinct object tree and top level objects.

pub fn instantiate_with_owner_top_level_objects<T>( &self, owner: id, top_lvl_objects: Option<NSArray<T>>, )

Instantiates objects in the nib file with the specified owner.

Methods from Deref<Target = Object>

pub fn class(&self) -> &Class

Returns the class of self.

pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

Returns a reference to the ivar of self with the given name. Panics if self has no ivar with the given name. Unsafe because the caller must ensure that the ivar is actually of type T.

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

Returns a mutable reference to the ivar of self with the given name. Panics if self has no ivar with the given name. Unsafe because the caller must ensure that the ivar is actually of type T.

pub unsafe fn set_ivar<T>(&mut self, name: &str, value: T)
where T: Encode,

Sets the value of the ivar of self with the given name. Panics if self has no ivar with the given name. Unsafe because the caller must ensure that the ivar is actually of type T.