pub trait INSNib: PNSObject {
// Provided methods
fn m_init_with_contents_of_url(&mut self, nib_file_url: NSURL) -> id { ... }
fn m_init_with_nib_named_bundle(
&mut self,
nib_name: NSNibName,
bundle: &NSBundle,
) -> Self
where Self: Sized + FromId { ... }
fn m_init_with_nib_data_bundle(
&mut self,
nib_data: &NSData,
bundle: &NSBundle,
) -> Self
where Self: Sized + FromId { ... }
fn m_instantiate_nib_with_owner_top_level_objects<T>(
&mut self,
owner: id,
top_lvl_objects: &NSArray<T>,
) -> bool { ... }
fn m_instantiate_nib_with_external_name_table<K, V>(
&self,
external_name_table: &NSDictionary<K, V>,
) -> bool { ... }
fn m_instantiate_with_owner_top_level_objects<T>(
&self,
owner: id,
top_lvl_objects: Option<NSArray<T>>,
) { ... }
}Expand description
A trait containing all the methods for NSNib
Provided Methods
Sourcefn m_init_with_contents_of_url(&mut self, nib_file_url: NSURL) -> id
👎Deprecated: use [init_with_nib_data_bundle] instead.
fn m_init_with_contents_of_url(&mut self, nib_file_url: NSURL) -> id
use [init_with_nib_data_bundle] instead.
Returns an NSNib object initialized to the nib file at the specified URL.
Sourcefn m_init_with_nib_named_bundle(
&mut self,
nib_name: NSNibName,
bundle: &NSBundle,
) -> Self
fn m_init_with_nib_named_bundle( &mut self, nib_name: NSNibName, bundle: &NSBundle, ) -> Self
Returns an NSNib object initialized to the nib file in the specified bundle.
Sourcefn m_init_with_nib_data_bundle(
&mut self,
nib_data: &NSData,
bundle: &NSBundle,
) -> Self
fn m_init_with_nib_data_bundle( &mut self, nib_data: &NSData, bundle: &NSBundle, ) -> Self
Initializes an instance with nib data and specified bundle for locating resources.
Sourcefn m_instantiate_nib_with_owner_top_level_objects<T>(
&mut self,
owner: id,
top_lvl_objects: &NSArray<T>,
) -> bool
👎Deprecated: use [instantiate_with_owner_top_level_objects] instead.
fn m_instantiate_nib_with_owner_top_level_objects<T>( &mut self, owner: id, top_lvl_objects: &NSArray<T>, ) -> bool
use [instantiate_with_owner_top_level_objects] instead.
Unarchives and instantiates the in-memory contents of the receiver’s nib file, creating a distinct object tree and set of top level objects.
Sourcefn m_instantiate_nib_with_external_name_table<K, V>(
&self,
external_name_table: &NSDictionary<K, V>,
) -> bool
👎Deprecated: use [instantiate_with_owner_top_level_objects] instead.
fn m_instantiate_nib_with_external_name_table<K, V>( &self, external_name_table: &NSDictionary<K, V>, ) -> bool
use [instantiate_with_owner_top_level_objects] instead.
Unarchives and instantiates the in-memory contents of the receiver’s nib file, creating a distinct object tree and top level objects.
Sourcefn m_instantiate_with_owner_top_level_objects<T>(
&self,
owner: id,
top_lvl_objects: Option<NSArray<T>>,
)
fn m_instantiate_with_owner_top_level_objects<T>( &self, owner: id, top_lvl_objects: Option<NSArray<T>>, )
Instantiates objects in the nib file with the specified owner.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".