pub trait INSStoryboard: PNSObject {
// Provided methods
fn tm_storyboard_with_name_bundle(
name: NSStoryboardName,
bundle: Option<NSBundle>,
) -> Self
where Self: Sized + FromId { ... }
fn tp_main_storyboard() -> NSStoryboard { ... }
fn im_instantiate_initial_controller(&self) -> id { ... }
}Expand description
An encapsulation of the design-time view controller and window controller graph represented in an Interface Builder storyboard resource file.
Provided Methods
Sourcefn tm_storyboard_with_name_bundle(
name: NSStoryboardName,
bundle: Option<NSBundle>,
) -> Self
fn tm_storyboard_with_name_bundle( name: NSStoryboardName, bundle: Option<NSBundle>, ) -> Self
Creates a storyboard based on the named storyboard file in the specified bundle.
Sourcefn tp_main_storyboard() -> NSStoryboard
fn tp_main_storyboard() -> NSStoryboard
The app’s main storyboard.
Sourcefn im_instantiate_initial_controller(&self) -> id
fn im_instantiate_initial_controller(&self) -> id
Creates the initial view controller or window controller from a storyboard.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".