Request the system to launch your app in the background to run tasks.
Structs
- BGApp
Refresh Task - An object representing a short task typically used to refresh content that’s run while the app is in the background.
- BGApp
Refresh Task Request - A request to launch your app in the background to execute a short refresh task.
- BGProcessing
Task - A time-consuming processing task that runs while the app is in the background.
- BGProcessing
Task Request - A request to launch your app in the background to execute a processing task that can take minutes to complete.
- BGTask
- An abstract class representing a task that’s run while the app is in the background.
- BGTask
Request - An abstract class for representing task requests.
- BGTask
Scheduler - A class for scheduling task requests that launch your app in the background.
Traits
- IBGApp
Refresh Task - A trait containing all the methods for
BGAppRefreshTask - IBGApp
Refresh Task Request - A trait containing all the methods for
BGAppRefreshTaskRequest - IBGProcessing
Task - A trait containing all the methods for
BGProcessingTask - IBGProcessing
Task Request - A trait containing all the methods for
BGProcessingTaskRequest - IBGTask
- A trait containing all the methods for
BGTask - IBGTask
Request - A trait containing all the methods for
BGTaskRequest - IBGTask
Scheduler - A trait containing all the methods for
BGTaskScheduler