pub trait IBGProcessingTaskRequest: IBGTaskRequest {
// Provided methods
fn m_init_with_identifier(&mut self, identifier: NSString) -> Self
where Self: Sized + FromId { ... }
fn p_requires_external_power() -> bool { ... }
fn p_requires_network_connectivity() -> bool { ... }
}Expand description
A trait containing all the methods for BGProcessingTaskRequest
Provided Methods
Sourcefn m_init_with_identifier(&mut self, identifier: NSString) -> Self
fn m_init_with_identifier(&mut self, identifier: NSString) -> Self
Return a new processing task request for the specified identifier.
Sourcefn p_requires_external_power() -> bool
fn p_requires_external_power() -> bool
A Boolean specifying if the processing task requires a device connected to power.
Sourcefn p_requires_network_connectivity() -> bool
fn p_requires_network_connectivity() -> bool
A Boolean specifying if the processing task requires network connectivity.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.