Module contacts

Module contacts 

Access the user’s contacts and format and localize contact information.

Structs

CNChangeHistoryAddContactEvent
CNChangeHistoryAddGroupEvent
CNChangeHistoryEvent
CNChangeHistoryFetchRequest
CNContact
An immutable object that stores information about a single contact, such as the contact’s first name, phone numbers, and addresses.
CNContactFetchRequest
An object that defines the options to use when fetching contacts.
CNContactFormatter
An object that you use to format contact information before displaying it to the user.
CNContactProperty
An object that represents a property of a contact.
CNContactRelation
An immutable object that represents the relationship between one contact to another.
CNContactStore
The object that fetches and saves contacts, groups, and containers from the user’s contacts database.
CNContainer
An immutable object that represents a collection of contacts.
CNFetchRequest
CNFetchResult
CNGroup
An immutable object that represents a group of contacts.
CNInstantMessageAddress
An immutable object representing an instant message address for the contact.
CNLabeledValue
An immutable object that combines a contact property value with a label that describes that property.
CNMutableContact
A mutable object that stores information about a single contact, such as the contact’s first name, phone numbers, and addresses.
CNMutableGroup
A mutable object that represents a group of contacts.
CNMutablePostalAddress
A mutable representation of the postal address for a contact.
CNPhoneNumber
An immutable object representing a phone number for a contact.
CNPostalAddress
An immutable representation of the postal address for a contact.
CNSaveRequest
An object that collects the changes you want to save to the user’s contacts database.
CNSocialProfile
An immutable object that represents one of the user’s social profiles.

Enums

CNAuthorizationStatus
An authorization status the user can grant for an app to access the specified entity type.
CNContactDisplayNameOrder
CNContactFormatterStyle
CNContactSortOrder
Indicates the sorting order for contacts.
CNContactType
The types a contact can be.
CNContainerType
The container may be local on the device or associated with a server account that has contacts.
CNEntityType
The entities the user can grant access to.

Statics

CNContactBirthdayKey
The birthday of a contact.
CNContactDatesKey
Dates associated with a contact.
CNContactDepartmentNameKey
The contact’s department name.
CNContactEmailAddressesKey
The email addresses of the contact.
CNContactFamilyNameKey
The contact’s family name.
CNContactGivenNameKey
The contact’s given name.
CNContactIdentifierKey
The contact’s unique identifier.
CNContactImageDataAvailableKey
Image data availability for a contact.
CNContactImageDataKey
Image data for a contact.
CNContactInstantMessageAddressesKey
The instant message addresses of the contact.
CNContactJobTitleKey
The contact’s job title.
CNContactMiddleNameKey
The contact’s middle name.
CNContactNamePrefixKey
The prefix for the contact’s name.
CNContactNameSuffixKey
The contact’s name suffix.
CNContactNicknameKey
The contact’s nickname.
CNContactNonGregorianBirthdayKey
The non-Gregorian birthday of the contact.
CNContactNoteKey
A note associated with a contact.
CNContactOrganizationNameKey
The contact’s organization name.
CNContactPhoneNumbersKey
A phone numbers of a contact.
CNContactPhoneticFamilyNameKey
The phonetic spelling of the contact’s family name.
CNContactPhoneticGivenNameKey
The phonetic spelling of the contact’s given name.
CNContactPhoneticMiddleNameKey
The phonetic spelling of the contact’s middle name.
CNContactPhoneticOrganizationNameKey
The phonetic spelling of the contact’s organization name.
CNContactPostalAddressesKey
The postal addresses of the contact.
CNContactPreviousFamilyNameKey
The contact’s previous family name.
CNContactPropertyAttribute
The contact’s name component property key.
CNContactRelationsKey
The relationships of the contact.
CNContactSocialProfilesKey
A social profiles of a contact.
CNContactStoreDidChangeNotification
The shared contact store.
CNContactThumbnailImageDataKey
Thumbnail data for a contact.
CNContactTypeKey
The type of contact.
CNContactUrlAddressesKey
The URL addresses of the contact.
CNContainerNameKey
The name of the container.
CNContainerTypeKey
The type of the container.
CNGroupIdentifierKey
The identifier of the group.
CNGroupNameKey
The name of the group.
CNInstantMessageAddressServiceKey
Instant message address service key.
CNInstantMessageAddressUsernameKey
Instant message address username key.
CNLabelDateAnniversary
The label for identifying the contact’s anniversary date.
CNLabelEmailiCloud
The label for identifying the contact’s iCloud email information.
CNLabelHome
The label for identifying home information.
CNLabelOther
The label for identifying other information.
CNLabelSchool
The label for the contact’s school.
CNLabelURLAddressHomePage
The label for identifying URL information.
CNLabelWork
The label for identifying work information.
CNSocialProfileServiceKey
The social profile service.
CNSocialProfileURLStringKey
The social profile URL.
CNSocialProfileUserIdentifierKey
The social profile user identifier.
CNSocialProfileUsernameKey
The social profile user name.

Traits

ICNChangeHistoryAddContactEvent
A trait containing all the methods for CNChangeHistoryAddContactEvent
ICNChangeHistoryAddGroupEvent
A trait containing all the methods for CNChangeHistoryAddGroupEvent
ICNChangeHistoryEvent
A trait containing all the methods for CNChangeHistoryEvent
ICNChangeHistoryFetchRequest
A trait containing all the methods for CNChangeHistoryFetchRequest
ICNContact
A trait containing all the methods for CNContact
ICNContactFetchRequest
A trait containing all the methods for CNContactFetchRequest
ICNContactFormatter
A trait containing all the methods for CNContactFormatter
ICNContactProperty
A trait containing all the methods for CNContactProperty
ICNContactRelation
A trait containing all the methods for CNContactRelation
ICNContactStore
A trait containing all the methods for CNContactStore
ICNContainer
A trait containing all the methods for CNContainer
ICNFetchRequest
A trait containing all the methods for CNFetchRequest
ICNFetchResult
ICNGroup
A trait containing all the methods for CNGroup
ICNInstantMessageAddress
A trait containing all the methods for CNInstantMessageAddress
ICNLabeledValue
A trait containing all the methods for ICNLabeledValue
ICNMutableContact
A trait containing all the methods for CNMutableContact
ICNMutableGroup
A trait containing all the methods for CNMutableGroup
ICNMutablePostalAddress
A trait containing all the methods for CNMutablePostalAddress
ICNPhoneNumber
A trait containing all the methods for CNPhoneNumber
ICNPostalAddress
A trait containing all the methods for CNPostalAddress
ICNSaveRequest
A trait containing all the methods for CNSaveRequest
ICNSocialProfile
A trait containing all the methods for CNSocialProfile