Access the user’s contacts and format and localize contact information.
Structs
- CNChange
History AddContact Event - CNChange
History AddGroup Event - CNChange
History Event - CNChange
History Fetch Request - CNContact
- An immutable object that stores information about a single contact, such as the contact’s first name, phone numbers, and addresses.
- CNContact
Fetch Request - An object that defines the options to use when fetching contacts.
- CNContact
Formatter - An object that you use to format contact information before displaying it to the user.
- CNContact
Property - An object that represents a property of a contact.
- CNContact
Relation - An immutable object that represents the relationship between one contact to another.
- CNContact
Store - The object that fetches and saves contacts, groups, and containers from the user’s contacts database.
- CNContainer
- An immutable object that represents a collection of contacts.
- CNFetch
Request - CNFetch
Result - CNGroup
- An immutable object that represents a group of contacts.
- CNInstant
Message Address - An immutable object representing an instant message address for the contact.
- CNLabeled
Value - An immutable object that combines a contact property value with a label that describes that property.
- CNMutable
Contact - A mutable object that stores information about a single contact, such as the contact’s first name, phone numbers, and addresses.
- CNMutable
Group - A mutable object that represents a group of contacts.
- CNMutable
Postal Address - A mutable representation of the postal address for a contact.
- CNPhone
Number - An immutable object representing a phone number for a contact.
- CNPostal
Address - An immutable representation of the postal address for a contact.
- CNSave
Request - An object that collects the changes you want to save to the user’s contacts database.
- CNSocial
Profile - An immutable object that represents one of the user’s social profiles.
Enums
- CNAuthorization
Status - An authorization status the user can grant for an app to access the specified entity type.
- CNContact
Display Name Order - CNContact
Formatter Style - CNContact
Sort Order - Indicates the sorting order for contacts.
- CNContact
Type - The types a contact can be.
- CNContainer
Type - The container may be local on the device or associated with a server account that has contacts.
- CNEntity
Type - The entities the user can grant access to.
Statics
- CNContact
Birthday ⚠Key - The birthday of a contact.
- CNContact
Dates ⚠Key - Dates associated with a contact.
- CNContact
Department ⚠Name Key - The contact’s department name.
- CNContact
Email ⚠Addresses Key - The email addresses of the contact.
- CNContact
Family ⚠Name Key - The contact’s family name.
- CNContact
Given ⚠Name Key - The contact’s given name.
- CNContact
Identifier ⚠Key - The contact’s unique identifier.
- CNContact
Image ⚠Data Available Key - Image data availability for a contact.
- CNContact
Image ⚠Data Key - Image data for a contact.
- CNContact
Instant ⚠Message Addresses Key - The instant message addresses of the contact.
- CNContact
JobTitle ⚠Key - The contact’s job title.
- CNContact
Middle ⚠Name Key - The contact’s middle name.
- CNContact
Name ⚠Prefix Key - The prefix for the contact’s name.
- CNContact
Name ⚠Suffix Key - The contact’s name suffix.
- CNContact
Nickname ⚠Key - The contact’s nickname.
- CNContact
NonGregorian ⚠Birthday Key - The non-Gregorian birthday of the contact.
- CNContact
Note ⚠Key - A note associated with a contact.
- CNContact
Organization ⚠Name Key - The contact’s organization name.
- CNContact
Phone ⚠Numbers Key - A phone numbers of a contact.
- CNContact
Phonetic ⚠Family Name Key - The phonetic spelling of the contact’s family name.
- CNContact
Phonetic ⚠Given Name Key - The phonetic spelling of the contact’s given name.
- CNContact
Phonetic ⚠Middle Name Key - The phonetic spelling of the contact’s middle name.
- CNContact
Phonetic ⚠Organization Name Key - The phonetic spelling of the contact’s organization name.
- CNContact
Postal ⚠Addresses Key - The postal addresses of the contact.
- CNContact
Previous ⚠Family Name Key - The contact’s previous family name.
- CNContact
Property ⚠Attribute - The contact’s name component property key.
- CNContact
Relations ⚠Key - The relationships of the contact.
- CNContact
Social ⚠Profiles Key - A social profiles of a contact.
- CNContact
Store ⚠DidChange Notification - The shared contact store.
- CNContact
Thumbnail ⚠Image Data Key - Thumbnail data for a contact.
- CNContact
Type ⚠Key - The type of contact.
- CNContact
UrlAddresses ⚠Key - The URL addresses of the contact.
- CNContainer
Name ⚠Key - The name of the container.
- CNContainer
Type ⚠Key - The type of the container.
- CNGroup
Identifier ⚠Key - The identifier of the group.
- CNGroup
Name ⚠Key - The name of the group.
- CNInstant
Message ⚠Address Service Key - Instant message address service key.
- CNInstant
Message ⚠Address Username Key - Instant message address username key.
- CNLabel
Date ⚠Anniversary - The label for identifying the contact’s anniversary date.
- CNLabel
Emaili ⚠Cloud - The label for identifying the contact’s iCloud email information.
- CNLabel
Home ⚠ - The label for identifying home information.
- CNLabel
Other ⚠ - The label for identifying other information.
- CNLabel
School ⚠ - The label for the contact’s school.
- CNLabelURL
Address ⚠Home Page - The label for identifying URL information.
- CNLabel
Work ⚠ - The label for identifying work information.
- CNSocial
Profile ⚠Service Key - The social profile service.
- CNSocial
ProfileURL ⚠String Key - The social profile URL.
- CNSocial
Profile ⚠User Identifier Key - The social profile user identifier.
- CNSocial
Profile ⚠Username Key - The social profile user name.
Traits
- ICNChange
History AddContact Event - A trait containing all the methods for
CNChangeHistoryAddContactEvent - ICNChange
History AddGroup Event - A trait containing all the methods for
CNChangeHistoryAddGroupEvent - ICNChange
History Event - A trait containing all the methods for
CNChangeHistoryEvent - ICNChange
History Fetch Request - A trait containing all the methods for
CNChangeHistoryFetchRequest - ICNContact
- A trait containing all the methods for
CNContact - ICNContact
Fetch Request - A trait containing all the methods for
CNContactFetchRequest - ICNContact
Formatter - A trait containing all the methods for
CNContactFormatter - ICNContact
Property - A trait containing all the methods for
CNContactProperty - ICNContact
Relation - A trait containing all the methods for
CNContactRelation - ICNContact
Store - A trait containing all the methods for
CNContactStore - ICNContainer
- A trait containing all the methods for
CNContainer - ICNFetch
Request - A trait containing all the methods for
CNFetchRequest - ICNFetch
Result - ICNGroup
- A trait containing all the methods for
CNGroup - ICNInstant
Message Address - A trait containing all the methods for
CNInstantMessageAddress - ICNLabeled
Value - A trait containing all the methods for
ICNLabeledValue“ - ICNMutable
Contact - A trait containing all the methods for
CNMutableContact - ICNMutable
Group - A trait containing all the methods for
CNMutableGroup - ICNMutable
Postal Address - A trait containing all the methods for
CNMutablePostalAddress - ICNPhone
Number - A trait containing all the methods for
CNPhoneNumber - ICNPostal
Address - A trait containing all the methods for
CNPostalAddress - ICNSave
Request - A trait containing all the methods for
CNSaveRequest - ICNSocial
Profile - A trait containing all the methods for
CNSocialProfile