#[repr(i64)]pub enum CNContainerType {
Unassigned = 0,
Local = 1,
Exchange = 2,
CardDav = 3,
}Expand description
The container may be local on the device or associated with a server account that has contacts.
Variants
Unassigned = 0
Local = 1
A container for contacts only stored locally on the device. There is only one local container for a device.
Exchange = 2
A container for contacts stored in an Exchange folder from an Exchange server.
CardDav = 3
A container for contacts stored in an CardDAV server, such as iCloud.