pub trait ICNContactFetchRequest: ICNFetchRequest {
// Provided methods
fn m_init_with_keys_to_fetch(&self, keys: NSArray<id>) -> Self
where Self: Sized + FromId { ... }
fn p_predicate(&self) -> NSPredicate { ... }
fn p_set_predicate(&mut self, predicate: NSPredicate) { ... }
fn p_mutable_objects(&self) -> bool { ... }
fn p_set_mutable_objects(&mut self, mutable_objects: bool) { ... }
fn p_unify_results(&self) -> bool { ... }
fn p_set_unify_results(&mut self, unify_results: bool) { ... }
fn p_sort_order(&self) -> CNContactSortOrder { ... }
fn p_keys_to_fetch(&self) -> NSArray<id> { ... }
fn p_set_keys_to_fetch(&mut self, keys_to_fetch: NSArray<id>) { ... }
}Expand description
A trait containing all the methods for CNContactFetchRequest
Provided Methods
Sourcefn m_init_with_keys_to_fetch(&self, keys: NSArray<id>) -> Self
fn m_init_with_keys_to_fetch(&self, keys: NSArray<id>) -> Self
Creates a fetch request for the specified keys.
Sourcefn p_predicate(&self) -> NSPredicate
fn p_predicate(&self) -> NSPredicate
The predicate to match contacts against.
Sourcefn p_set_predicate(&mut self, predicate: NSPredicate)
fn p_set_predicate(&mut self, predicate: NSPredicate)
Sets the predicate to match contacts against.
Sourcefn p_mutable_objects(&self) -> bool
fn p_mutable_objects(&self) -> bool
Configuring the Fetch Options
Sourcefn p_set_mutable_objects(&mut self, mutable_objects: bool)
fn p_set_mutable_objects(&mut self, mutable_objects: bool)
Sets whether the fetch request should return mutable objects.
Sourcefn p_unify_results(&self) -> bool
fn p_unify_results(&self) -> bool
A Boolean value that indicates whether to return linked contacts as unified contacts.
Sourcefn p_set_unify_results(&mut self, unify_results: bool)
fn p_set_unify_results(&mut self, unify_results: bool)
Sets whether to return linked contacts as unified contacts.
Sourcefn p_sort_order(&self) -> CNContactSortOrder
fn p_sort_order(&self) -> CNContactSortOrder
The sort order for contacts.
Sourcefn p_keys_to_fetch(&self) -> NSArray<id>
fn p_keys_to_fetch(&self) -> NSArray<id>
The properties to fetch in the returned contacts.
Sourcefn p_set_keys_to_fetch(&mut self, keys_to_fetch: NSArray<id>)
fn p_set_keys_to_fetch(&mut self, keys_to_fetch: NSArray<id>)
Sets the properties to fetch in the returned contacts.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.