pub trait ICNMutableContact: ICNContact {
Show 26 methods
// Provided methods
fn p_set_name_prefix(&mut self, name_prefix: NSString) { ... }
fn p_set_given_name(&mut self, given_name: NSString) { ... }
fn p_set_middle_name(&mut self, middle_name: NSString) { ... }
fn p_set_family_name(&mut self, family_name: NSString) { ... }
fn p_set_previous_family_name(&mut self, previous_family_name: NSString) { ... }
fn p_set_name_suffix(&mut self, name_suffix: NSString) { ... }
fn p_set_nickname(&mut self, nickname: NSString) { ... }
fn p_set_phonetic_given_name(&mut self, phonetic_given_name: NSString) { ... }
fn p_set_phonetic_middle_name(&mut self, phonetic_middle_name: NSString) { ... }
fn p_set_phonetic_family_name(&mut self, phonetic_family_name: NSString) { ... }
fn p_set_job_title(&mut self, job_title: NSString) { ... }
fn p_set_department_name(&mut self, department_name: NSString) { ... }
fn p_set_organization_name(&mut self, organization_name: NSString) { ... }
fn p_set_phonetic_organization_name(
&mut self,
phonetic_organization_name: NSString,
) { ... }
fn p_set_postal_addresses<PostalAddress>(
&mut self,
postal_addresses: NSArray<CNLabeledValue<PostalAddress>>,
)
where PostalAddress: ICNPostalAddress { ... }
fn p_set_email_addresses(
&mut self,
email_addresses: NSArray<CNLabeledValue<NSString>>,
) { ... }
fn p_set_url_addresses(
&mut self,
url_addresses: NSArray<CNLabeledValue<NSString>>,
) { ... }
fn p_set_phone_numbers(
&mut self,
phone_numbers: NSArray<CNLabeledValue<CNPhoneNumber>>,
) { ... }
fn p_set_social_profiles(
&mut self,
social_profiles: NSArray<CNLabeledValue<CNSocialProfile>>,
) { ... }
fn p_set_dates(&mut self, dates: NSArray<CNLabeledValue<NSDateComponents>>) { ... }
fn p_set_non_gregorian_birthday(
&mut self,
non_gregorian_birthday: NSDateComponents,
) { ... }
fn p_set_birthday(&mut self, birthday: NSDateComponents) { ... }
fn p_set_note(&mut self, note: NSString) { ... }
fn p_set_image_data(&mut self, image_data: NSData) { ... }
fn p_set_contact_relations(
&mut self,
contact_relations: NSArray<CNLabeledValue<CNContactRelation>>,
) { ... }
fn p_set_instant_messenger_addresses(
&mut self,
instant_messenger_addresses: NSArray<CNLabeledValue<CNInstantMessageAddress>>,
) { ... }
}Expand description
A trait containing all the methods for CNMutableContact
Provided Methods
Sourcefn p_set_name_prefix(&mut self, name_prefix: NSString)
fn p_set_name_prefix(&mut self, name_prefix: NSString)
Sets the name prefix of the contact.
Sourcefn p_set_given_name(&mut self, given_name: NSString)
fn p_set_given_name(&mut self, given_name: NSString)
Sets the given name of the contact.
Sourcefn p_set_middle_name(&mut self, middle_name: NSString)
fn p_set_middle_name(&mut self, middle_name: NSString)
Sets the middle name of the contact.
Sourcefn p_set_family_name(&mut self, family_name: NSString)
fn p_set_family_name(&mut self, family_name: NSString)
Sets the family name of the contact.
Sourcefn p_set_previous_family_name(&mut self, previous_family_name: NSString)
fn p_set_previous_family_name(&mut self, previous_family_name: NSString)
Sets the previous family name of the contact.
Sourcefn p_set_name_suffix(&mut self, name_suffix: NSString)
fn p_set_name_suffix(&mut self, name_suffix: NSString)
Sets the name suffix of the contact.
Sourcefn p_set_nickname(&mut self, nickname: NSString)
fn p_set_nickname(&mut self, nickname: NSString)
Sets the nickname of the contact.
Sourcefn p_set_phonetic_given_name(&mut self, phonetic_given_name: NSString)
fn p_set_phonetic_given_name(&mut self, phonetic_given_name: NSString)
Sets the phonetic given name of the contact.
Sourcefn p_set_phonetic_middle_name(&mut self, phonetic_middle_name: NSString)
fn p_set_phonetic_middle_name(&mut self, phonetic_middle_name: NSString)
Sets the phonetic middle name of the contact.
Sourcefn p_set_phonetic_family_name(&mut self, phonetic_family_name: NSString)
fn p_set_phonetic_family_name(&mut self, phonetic_family_name: NSString)
Sets the phonetic family name of the contact.
Sourcefn p_set_job_title(&mut self, job_title: NSString)
fn p_set_job_title(&mut self, job_title: NSString)
The contact’s job title.
Sourcefn p_set_department_name(&mut self, department_name: NSString)
fn p_set_department_name(&mut self, department_name: NSString)
The name of the department associated with the contact.
Sourcefn p_set_organization_name(&mut self, organization_name: NSString)
fn p_set_organization_name(&mut self, organization_name: NSString)
The name of the organization associated with the contact.
Sourcefn p_set_phonetic_organization_name(
&mut self,
phonetic_organization_name: NSString,
)
fn p_set_phonetic_organization_name( &mut self, phonetic_organization_name: NSString, )
The phonetic name of the organization associated with the contact.
Sourcefn p_set_postal_addresses<PostalAddress>(
&mut self,
postal_addresses: NSArray<CNLabeledValue<PostalAddress>>,
)where
PostalAddress: ICNPostalAddress,
fn p_set_postal_addresses<PostalAddress>(
&mut self,
postal_addresses: NSArray<CNLabeledValue<PostalAddress>>,
)where
PostalAddress: ICNPostalAddress,
An array of labeled postal addresses for a contact.
Sourcefn p_set_email_addresses(
&mut self,
email_addresses: NSArray<CNLabeledValue<NSString>>,
)
fn p_set_email_addresses( &mut self, email_addresses: NSArray<CNLabeledValue<NSString>>, )
An array of labeled email addresses for a contact.
Sourcefn p_set_url_addresses(
&mut self,
url_addresses: NSArray<CNLabeledValue<NSString>>,
)
fn p_set_url_addresses( &mut self, url_addresses: NSArray<CNLabeledValue<NSString>>, )
An array of labeled URL addresses for a contact.
Sourcefn p_set_phone_numbers(
&mut self,
phone_numbers: NSArray<CNLabeledValue<CNPhoneNumber>>,
)
fn p_set_phone_numbers( &mut self, phone_numbers: NSArray<CNLabeledValue<CNPhoneNumber>>, )
An array of labeled phone numbers for a contact.
An array of labeled social profiles for a contact.
Sourcefn p_set_dates(&mut self, dates: NSArray<CNLabeledValue<NSDateComponents>>)
fn p_set_dates(&mut self, dates: NSArray<CNLabeledValue<NSDateComponents>>)
An array containing labeled Gregorian dates.
Sourcefn p_set_non_gregorian_birthday(
&mut self,
non_gregorian_birthday: NSDateComponents,
)
fn p_set_non_gregorian_birthday( &mut self, non_gregorian_birthday: NSDateComponents, )
A date component for the non-Gregorian birthday of the contact.
Sourcefn p_set_birthday(&mut self, birthday: NSDateComponents)
fn p_set_birthday(&mut self, birthday: NSDateComponents)
A date component for the Gregorian birthday of the contact.
Sourcefn p_set_note(&mut self, note: NSString)
fn p_set_note(&mut self, note: NSString)
A string containing notes for the contact.
Sourcefn p_set_image_data(&mut self, image_data: NSData)
fn p_set_image_data(&mut self, image_data: NSData)
Setting Images
Sourcefn p_set_contact_relations(
&mut self,
contact_relations: NSArray<CNLabeledValue<CNContactRelation>>,
)
fn p_set_contact_relations( &mut self, contact_relations: NSArray<CNLabeledValue<CNContactRelation>>, )
An array of labeled contact relations for the contact.
Sourcefn p_set_instant_messenger_addresses(
&mut self,
instant_messenger_addresses: NSArray<CNLabeledValue<CNInstantMessageAddress>>,
)
fn p_set_instant_messenger_addresses( &mut self, instant_messenger_addresses: NSArray<CNLabeledValue<CNInstantMessageAddress>>, )
An array of labeled IM addresses for the contact.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".