pub struct NSMutableDictionary<K, V> {
pub ptr: Id<Object>,
/* private fields */
}Expand description
A dynamic collection of objects associated with unique keys.
Fields
ptr: Id<Object>The raw pointer to the Objective-C object.
Implementations
Sourceimpl<K, V> NSMutableDictionary<K, V>
impl<K, V> NSMutableDictionary<K, V>
Sourcepub fn with_capacity(capacity: UInt) -> Self
pub fn with_capacity(capacity: UInt) -> Self
Creates a new dictionary with the specified capacity.
Methods from Deref<Target = Object>
Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Returns a reference to the ivar of self with the given name.
Panics if self has no ivar with the given name.
Unsafe because the caller must ensure that the ivar is actually
of type T.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Returns a mutable reference to the ivar of self with the given name.
Panics if self has no ivar with the given name.
Unsafe because the caller must ensure that the ivar is actually
of type T.