pub trait INSNotification: PNSObject {
// Provided methods
fn m_init(&mut self) -> Self
where Self: Sized + FromId { ... }
fn m_init_with_coder(&mut self, coder: &NSCoder) -> Self
where Self: Sized + FromId { ... }
fn m_notification_with_name_object(
name: NSNotificationName,
object: id,
) -> Self
where Self: Sized + FromId { ... }
fn m_notification_with_name_object_user_info(
name: NSNotificationName,
object: id,
user_info: NSDictionary<id, id>,
) -> Self
where Self: Sized + FromId { ... }
fn m_init_with_name_object_user_info(
&mut self,
name: &NSNotificationName,
object: id,
user_info: &NSDictionary<id, id>,
) -> Self
where Self: Sized + FromId { ... }
fn m_name(&self) -> NSNotificationName { ... }
fn m_object(&self) -> id { ... }
fn m_user_info(&self) -> NSDictionary<id, id> { ... }
}Expand description
A trait containing all the methods for NSNotification
Provided Methods
Sourcefn m_init_with_coder(&mut self, coder: &NSCoder) -> Self
fn m_init_with_coder(&mut self, coder: &NSCoder) -> Self
Initializes a notification with the data from an unarchiver.
Sourcefn m_notification_with_name_object(name: NSNotificationName, object: id) -> Self
fn m_notification_with_name_object(name: NSNotificationName, object: id) -> Self
Returns a new notification object with a specified name and object.
Sourcefn m_notification_with_name_object_user_info(
name: NSNotificationName,
object: id,
user_info: NSDictionary<id, id>,
) -> Self
fn m_notification_with_name_object_user_info( name: NSNotificationName, object: id, user_info: NSDictionary<id, id>, ) -> Self
Returns a notification object with a specified name, object, and user information.
Sourcefn m_init_with_name_object_user_info(
&mut self,
name: &NSNotificationName,
object: id,
user_info: &NSDictionary<id, id>,
) -> Self
fn m_init_with_name_object_user_info( &mut self, name: &NSNotificationName, object: id, user_info: &NSDictionary<id, id>, ) -> Self
Initializes a notification with a specified name, object, and user information.
Sourcefn m_name(&self) -> NSNotificationName
fn m_name(&self) -> NSNotificationName
The name of the notification.
Sourcefn m_user_info(&self) -> NSDictionary<id, id>
fn m_user_info(&self) -> NSDictionary<id, id>
The user information dictionary associated with the notification.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".