pub trait INLModelConfiguration: PNSObject {
// Provided methods
fn p_language(&self) -> Option<NLLanguage> { ... }
fn p_revision(&self) -> UInt { ... }
fn m_supported_revisions_for_type(type: NLModelType) -> NSIndexSet { ... }
fn m_current_revision_for_type(type: NLModelType) -> UInt { ... }
fn p_ml_type(&self) -> NLModelType { ... }
}Expand description
A trait containing all the methods for NLModelConfiguration
Provided Methods
Sourcefn p_language(&self) -> Option<NLLanguage>
fn p_language(&self) -> Option<NLLanguage>
The language the model supports.
Sourcefn p_revision(&self) -> UInt
fn p_revision(&self) -> UInt
The version of the Natural Language framework that trained the model.
Sourcefn m_supported_revisions_for_type(type: NLModelType) -> NSIndexSet
fn m_supported_revisions_for_type(type: NLModelType) -> NSIndexSet
Returns the versions of the Natural Language framework the OS supports.
Sourcefn m_current_revision_for_type(type: NLModelType) -> UInt
fn m_current_revision_for_type(type: NLModelType) -> UInt
Returns the current Natural Language framework version in the OS.
Sourcefn p_ml_type(&self) -> NLModelType
fn p_ml_type(&self) -> NLModelType
The natural language model type of the model.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".