pub trait IUNNotificationAction: PNSObject {
// Provided methods
fn m_action_with_identifier_title_options(
identifier: NSString,
title: NSString,
options: &[UNNotificationActionOptions],
) -> Self
where Self: Sized + FromId { ... }
fn m_action_with_identifier_title_options_icon(
identifier: NSString,
title: NSString,
options: &[UNNotificationActionOptions],
icon: UNNotificationActionIcon,
) -> Self
where Self: Sized + FromId { ... }
fn p_identifier(&self) -> NSString { ... }
fn p_title(&self) -> NSString { ... }
fn p_icon(&self) -> Option<UNNotificationActionIcon> { ... }
fn p_options(&self) -> UNNotificationActionOptions { ... }
}Expand description
A trait containing all the methods for UNNotificationAction
Provided Methods
Sourcefn m_action_with_identifier_title_options(
identifier: NSString,
title: NSString,
options: &[UNNotificationActionOptions],
) -> Self
fn m_action_with_identifier_title_options( identifier: NSString, title: NSString, options: &[UNNotificationActionOptions], ) -> Self
Creates an action object by using the specified title and options.
fn m_action_with_identifier_title_options_icon( identifier: NSString, title: NSString, options: &[UNNotificationActionOptions], icon: UNNotificationActionIcon, ) -> Self
Sourcefn p_identifier(&self) -> NSString
fn p_identifier(&self) -> NSString
The unique string that your app uses to identify the action.
Sourcefn p_icon(&self) -> Option<UNNotificationActionIcon>
fn p_icon(&self) -> Option<UNNotificationActionIcon>
The icon associated with the action.
Sourcefn p_options(&self) -> UNNotificationActionOptions
fn p_options(&self) -> UNNotificationActionOptions
The behaviors associated with the action.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".