pub trait IUNNotificationRequest: PNSObject {
// Provided methods
fn m_request_with_identifier_content_trigger(
identifier: &NSString,
content: &UNNotificationContent,
trigger: &UNNotificationTrigger,
) -> Self
where Self: Sized + FromId { ... }
fn p_identifier(&self) -> NSString { ... }
fn p_content(&self) -> UNNotificationContent { ... }
fn p_trigger(&self) -> Option<UNNotificationTrigger> { ... }
}Expand description
A trait containing all the methods for UNNotificationRequest
Provided Methods
Sourcefn m_request_with_identifier_content_trigger(
identifier: &NSString,
content: &UNNotificationContent,
trigger: &UNNotificationTrigger,
) -> Self
fn m_request_with_identifier_content_trigger( identifier: &NSString, content: &UNNotificationContent, trigger: &UNNotificationTrigger, ) -> Self
Creates a notification request object that you use to schedule a notification.
Sourcefn p_identifier(&self) -> NSString
fn p_identifier(&self) -> NSString
The unique identifier for this notification request.
Sourcefn p_content(&self) -> UNNotificationContent
fn p_content(&self) -> UNNotificationContent
The content associated with the notification.
Sourcefn p_trigger(&self) -> Option<UNNotificationTrigger>
fn p_trigger(&self) -> Option<UNNotificationTrigger>
The conditions that trigger the delivery of the notification.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".